<?xml version="1.0"?>
<!--
 | Copyright 2006 The JA-SIG Collaborative.  All rights reserved.
 | See license distributed with this file and
 | available online at http://www.uportal.org/license.html
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<!-- Use Narrow Wide Column Width controls -->
	<!-- 
		 If Use is set to true, then the value of NARROW_COLUMN_WIDTH will determine whether or not a column is narrow.
		 If it is not narrow, then it will be treated as a Wide column. The NARROW_COLUMN_WIDTH will be used as a percentage
		 of the screen width, unless the average column width (100/total # of columns is less than the NARROW_COLUMN_WIDTH).
		 In that case, it will automatically re-calculate the widths to make sure the Wide columns remain larger than the Narrow
		 columns.
		 
		 If Use is set to false, then the individual columns widths can be set by hand.  It will be up to the user to insure the values
		 balance.
	-->
	<xsl:variable name = "USE_WIDE_NARROW_COLUMNS">true</xsl:variable>
	<xsl:variable name = "NARROW_COLUMN_WIDTH">30</xsl:variable><!-- Value as a percentage of the screen -->
	
	<!-- Use Auto Move for Tabs -->
	<!-- 'true' means select movement by arrows, 'false' means selecting Move then selecting Location -->
	<xsl:variable name = "USE_TAB_AUTO_MOVE">true</xsl:variable>
	<!-- Use Auto Move for Columns -->
	<!-- 'true' means select movement by arrows, 'false' means selecting Move then selecting Location -->
	<xsl:variable name = "USE_COLUMN_AUTO_MOVE">true</xsl:variable>
	<!-- Use Auto Move for Content -->
	<!-- 'true' means select movement by arrows, 'false' means selecting Move then selecting Location -->
	<xsl:variable name = "USE_CONTENT_AUTO_MOVE">true</xsl:variable>
	<!-- Use Auto Add for Tabs -->
	<!-- 'true' means automatically add new tab to the end, 'false' means selecting the add tab location -->
	<xsl:variable name = "USE_TAB_AUTO_ADD">true</xsl:variable>
	<!-- Use Auto Add for Columns -->
	<!-- 'true' means automatically add new columns to the end, 'false' means selecting the add column location -->
	<xsl:variable name = "USE_COLUMN_AUTO_ADD">true</xsl:variable>
	<!-- Use Auto Add for Content -->
	<!-- 'true' means automatically add new content into the selected tab, in the first column, 'false' means selecting the add content location -->
	<xsl:variable name = "USE_CONTENT_AUTO_ADD">true</xsl:variable>
    
    <!-- 'true' means drag-and-drop portlet management will be turned on -->
    <xsl:variable name = "AJAX_LAYOUT_MANAGEMENT">true</xsl:variable>

	<!-- Show Log Off in Persistent Navigation -->
	<!-- 'true' means it will be rendered in Persistent Nav, 'false' means it will not -->
	<xsl:variable name = "SHOW_LOG_OFF_IN_PERSISTENT_NAV">false</xsl:variable>

	<!-- PAGE_TITLE -->
	<!-- Text shown in the browser window title bar -->
	<xsl:variable name = "PAGE_TITLE"><xsl:value-of select="$uP_productAndVersion" /></xsl:variable>
	
	
	<!-- PAGE_TITLE_FOCUSED -->
	<!-- Text shown in the browser window title bar -->
	<xsl:variable name = "PAGE_TITLE_FOCUSED"><xsl:value-of select="$uP_productAndVersion" /></xsl:variable>
	

	<!-- PAGE_TITLE_PREFERENCES -->
	<!-- Text shown in the browser window title bar -->
	<xsl:variable name = "PAGE_TITLE_PREFERENCES"><xsl:value-of select="$uP_productAndVersion" /></xsl:variable>
	

	<!-- DETACHED_PAGE_TITLE -->
	<!-- Text shown in the browser window title bar (for detached windows only) -->
	<xsl:variable name = "DETACHED_PAGE_TITLE"><xsl:value-of select="content/channel/@name" /></xsl:variable>
	
	
	<!-- SHOW_PORTLET_MANAGER -->
	<!-- Flag that sets whether or not the Portlet Manager link should be displayed or not -->
	<!-- VALUE: true or false -->
	<xsl:variable name = "SHOW_PORTLET_MANAGER">
		<xsl:choose>
			<xsl:when test="$authorizedChannelPublisher='true'">true</xsl:when>
			<xsl:otherwise>false</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>


	<!-- SHOW_PREFERENCES -->
	<!-- Flag that sets whether or not the Preferences link should be displayed or not -->
	<!-- VALUE: true or false -->
	<xsl:variable name = "SHOW_PREFERENCES">
		<!-- Show when authenticated user -->
		<xsl:choose>
			<xsl:when test="$authenticated='true'">true</xsl:when>
			<xsl:otherwise>false</xsl:otherwise>
		</xsl:choose>
		<!-- OPTIONS:  Other options might be to only show to certain userNames (i.e. Template user names) -->
	</xsl:variable>


	<!-- #### -->
    <!-- HEAD -->
	<!-- #### -->
	<!-- 
	Used to insert any valid XML or XSL into the head of the HTML document <head />, 
	specifically <link />'s, <script />'s, <style />'s, and <meta />'s 
	-->
    <xsl:template name="HEAD">
        <meta http-equiv="expires" content="Wed, 26 Feb 1997 08:21:57 GMT"/>
        <meta http-equiv="pragma" content="no-cache"/>
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
        <style type="text/css">@import url("<xsl:value-of select="$pathToPortlets" />/common.css");</style>
        <link type="text/css" rel="stylesheet" href="{$mediaPathSkin}/{$skin}.css"/>
        <!-- Add Conditional Comments for IE to load IE specific CSS -->
		<xsl:comment>[if IE]&gt; 
		&lt;style type="text/css"&gt;@import url("<xsl:value-of select="$mediaPathSkin" />/IE.css");&lt;/style&gt; 
		&lt;![endif]</xsl:comment>
        <link rel="Shortcut Icon" href="{$contextPath}/favicon.ico" type="image/x-icon" />
        <script type="text/javascript">
    	<![CDATA[

			function openBrWindow(theURL,winName,features)
			{window.open(theURL,winName,features).focus();}

		]]>
    	</script>
        <xsl:if test = "($AJAX_LAYOUT_MANAGEMENT = 'true') and ($authenticated = 'true')">
            <!-- ajax layout management -->
            <script type="text/javascript" src="{$mediaPath}/jquery-1.0.1.pack.js"><xsl:text>&#160;</xsl:text></script>
            <script type="text/javascript" src="{$mediaPath}/interface.js"><xsl:text>&#160;</xsl:text></script>
            <script type="text/javascript">
                <![CDATA[
    $(document).ready(
        function () {
		    $('li.portlet-tab-inactive-target').Droppable(
                {
                    accept :		'portlet-movable', 
                    activeclass:	'ajaxactive', 
                    hoverclass:		'ajaxhover',
                    tolerance:		'pointer',
                    onDrop:    function(drag) {
                        var baseActionUrl=']]><xsl:value-of select="$baseActionURL"/><![CDATA[?';
                        var firstColumnId=$(this).attr('firstColumnId');
                        var nextId=$(this).attr('firstPortletId');
                        var currentId=$(drag).attr('id');
                        var tabId=$(this).attr('tabId');
                        var targetUrl=baseActionUrl+jQuery.param({uP_sparam: 'focusedTabID', focusedTabID: tabId, uP_move_target: currentId, targetNextID: nextId, targetParentID: firstColumnId});
                        window.location.href=targetUrl;
                    }
                }
            );
                    
            $('div.portlet-ajax-target').Sortable(
                {
                    accept : 		'portlet-movable',
                    handle : 		'div.portlet-head',
                    activeclass : 	'ajaxactive',
                    hoverclass : 	'ajaxhover',
                    helperclass : 	'sorthelper',
                    opacity: 		0.8,
                    fx:				400,
                    revert:			false,
                    tolerance:		'pointer',
                    onStart:    function() {
                        $(this).attr('sortable.parentId',$(this).parent().attr('id'));
                        $(this).attr('sortable.nextId',$(this).next().attr('id'));
                    },
                    onStop:		function()
                    {
                        var baseActionUrl=']]><xsl:value-of select="$baseActionURL"/><![CDATA[';
                        var nextId=$(this).next().attr('id');
                        var currentId=$(this).attr('id');
                        var parentId=$(this).parent().attr('id');
                        var oldParentId=$(this).attr('sortable.parentId');
                        var oldNextId=$(this).attr('sortable.nextId');
                        if(oldNextId != nextId || oldParentId != parentId) {
                            if(currentId == nextId) { nextId=''; }
                            $.post(baseActionUrl,{ uP_context: 'ajax', uP_move_target: currentId, targetNextID: nextId, targetParentID: parentId });
                        }
                    }
    
                }
            );

            
       }

    );            
                ]]>
                </script>   
            </xsl:if>     
        
    </xsl:template>	


	<!-- ########## -->
    <!-- BODY_START -->
	<!-- ########## -->
	<!-- 
	Used to insert any valid XML or XSL into the HTML document <body />, 
	before any other content 
	-->
    <xsl:template name="BODY_START">
		<!-- -->
		<a href="#tabNavigation" title="{$token[@name='SKIP_TO_NAV_TITLE']}" id="skipToNav"><xsl:value-of select="$token[@name='SKIP_TO_NAV']" /></a>
		<a href="#startContent" title="{$token[@name='SKIP_TO_CONTENT_TITLE']}" id="skipToContent"><xsl:value-of select="$token[@name='SKIP_TO_CONTENT']" /></a>
    </xsl:template>	


	<!-- ######## -->
    <!-- BODY_END -->
	<!-- ######## -->
	<!-- 
	Used to insert any valid XML or XSL into the HTML document <body />, 
	after all other content 
	-->
    <xsl:template name="BODY_END"></xsl:template>	


	<!-- ################## -->
    <!-- BODY_START_FOCUSED -->
	<!-- ################## -->
	<!-- 
	Used to insert any valid XML or XSL into the HTML document <body />, 
	before any other content (in Focused Portlet view) 
	-->
    <xsl:template name="BODY_START_FOCUSED">
		<!-- -->
		<a href="#tabNavigation" title="{$token[@name='SKIP_TO_NAV_TITLE']}" id="skipToNav"><xsl:value-of select="$token[@name='SKIP_TO_NAV']" /></a>
		<a href="#startContent" title="{$token[@name='SKIP_TO_CONTENT_TITLE']}" id="skipToContent"><xsl:value-of select="$token[@name='SKIP_TO_CONTENT']" /></a>
    </xsl:template>	


	<!-- ################ -->
    <!-- BODY_END_FOCUSED -->
	<!-- ################ -->
	<!-- 
	Used to insert any valid XML or XSL into the HTML document <body />, 
	after all other content (in Focused Portlet view) 
	-->
    <xsl:template name="BODY_END_FOCUSED"></xsl:template>	


	<!-- ###################### -->
    <!-- BODY_START_PREFERENCES -->
	<!-- ###################### -->
	<!-- 
	Used to insert any valid XML or XSL into the HTML document <body />, 
	before any other content (in Preferences/Customize view) 
	-->
    <xsl:template name="BODY_START_PREFERENCES">
		<!-- -->
		<a href="#tabNavigation" title="{$token[@name='SKIP_TO_NAV_TITLE']}" id="skipToNav"><xsl:value-of select="$token[@name='SKIP_TO_NAV']" /></a>
		<a href="#startContent" title="{$token[@name='SKIP_TO_CONTENT_TITLE']}" id="skipToContent"><xsl:value-of select="$token[@name='SKIP_TO_CONTENT']" /></a>
    </xsl:template>	


	<!-- #################### -->
    <!-- BODY_END_PREFERENCES -->
	<!-- #################### -->
	<!-- 
	Used to insert any valid XML or XSL into the HTML document <body />, 
	after all other content (in Preferences/Customize view)
	-->
    <xsl:template name="BODY_END_PREFERENCES"></xsl:template>	


	<!-- ######### -->
    <!-- MAIN_LOGO -->
	<!-- ######### -->
	<!-- 
	Used to insert any valid XML or XSL into the head of the page, typically where
	the main site logo is displayed.
	-->
	<xsl:template name="MAIN_LOGO">
		<div id="portal-top-bar">
			<h1><xsl:value-of select="$token[@name='TOP_BAR_TITLE']" /></h1>
		</div>
	    
	    <xsl:if test = "not($isFocused)">
		    <div id="portal-main-logo">
				<a href="{$baseActionURL}?uP_root=root&amp;uP_reload_layout=true&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true&amp;uP_sparam=mode&amp;mode=view" title="{$token[@name='LOGO_TITLE']}"><img src="{$mediaPathSkin}/mainlogo.gif" alt="{$token[@name='LOGO']}"/></a>
		    </div>
	    </xsl:if>
	</xsl:template>
	

	<!-- ##################### -->
    <!-- MAIN_LOGO_PREFERENCES -->
	<!-- ##################### -->
	<!-- 
	Used to insert any valid XML or XSL into the head of the page, typically where
	the main site logo is displayed.
	-->
	<xsl:template name="MAIN_LOGO_PREFERENCES">
		<div id="portal-top-bar">
			<h1><xsl:value-of select="$token[@name='TOP_BAR_TITLE']" /></h1>
		</div>
	</xsl:template>
	

	<!-- ####### -->
    <!-- WELCOME -->
	<!-- ####### -->
	<!-- 
	Used to insert any valid XML or XSL where typically is displayed a Welcome message to the User
	-->
	<xsl:template name="WELCOME">
        <xsl:if test = "not($isFocused)">
	        <div id="portal-welcome">
	            <div id="portal-welcome-inner">
	                <p><xsl:value-of select="$token[@name='WELCOME_PRE']" /><xsl:value-of select="$userName"/><xsl:value-of select="$token[@name='WELCOME_POST']" /></p>
	                <form action="/uP3/logout.jsp" method="post">
                	<xsl:call-template name = "TOP_BUTTONS" >
                		<xsl:with-param name="type">LOGOFF</xsl:with-param>
                		<!--<xsl:with-param name="url">/uP3/logout.jsp</xsl:with-param> -->
                		<xsl:with-param name="shortLabel" select="$token[@name='LOGOFF_LABEL']" />
                		<xsl:with-param name="longLabel" select="$token[@name='LOGOFF_LONG_LABEL']" />
                	</xsl:call-template>
        			</form>
	            </div>
	        </div>
        </xsl:if>
	</xsl:template>


	<!-- ##### -->
    <!-- LOGIN -->
	<!-- ##### -->
	<!-- 
	Used to insert any valid XML or XSL where typically is displayed a login form
	OPTIONS: Display Login channel, CAS Login Link, ...
	-->
	<xsl:template name="LOGIN">
        <div id="portal-login">
            <div id="portal-login-inner">
	            <div id="portal-login-header">
	                <div id="portal-login-header-inner">
	                    <h3><xsl:value-of select="$token[@name='WELCOME_LOGIN_HEADER']" /></h3>
	                </div>
	            </div>
	            <div id="portal-login-body">
	                <div id="portal-login-body-inner">
	                	<!-- Uncomment to use Login Channel -->
	                    <!--<xsl:copy-of select="channel"/> -->
	                    <form method="post" action="/uP3/j_acegi_security_check">
	                    	<fieldset>
		                    	<legend><xsl:value-of select="$token[@name='WELCOME_LOGIN_LEGEND']" /></legend>
		                    	<ol>
			                    	<li><label class="portal-login-username"><span><xsl:value-of select="$token[@name='WELCOME_LOGIN_USERNAME_LABEL']" /></span><input type="text" name="j_username" title="{$token[@name='WELCOME_LOGIN_USERNAME_FIELD_TITLE']}" /></label></li>
			                    	<li><label class="portal-login-password"><span><xsl:value-of select="$token[@name='WELCOME_LOGIN_PASSWORD_LABEL']" /></span><input type="password" name="j_password" title="{$token[@name='WELCOME_LOGIN_PASSWORD_FIELD_TITLE']}" /></label></li>
		                    	</ol>
	                    	</fieldset>
	                    	<div class="portal-login-controls-submit"><input type="submit" value="{$token[@name='WELCOME_LOGIN_BUTTON_LABEL']}" /></div>
	                    </form>
	                </div>
	            </div>
            </div>
        </div>
	</xsl:template>


	<!-- ###### -->
    <!-- FOOTER -->
	<!-- ###### -->
	<!-- 
	Used to insert any valid XML or XSL into the footer of the page.
	-->
	<xsl:template name="FOOTER">
		
		<xsl:if test = "$isPreferences">
			<xsl:call-template name = "preferenceInstructions" />
		</xsl:if>
		
		<div id="portal-footer">
			<div id="portal-footer-inner">
				<ul id="portal-footer-links">
					<li class="first"><a href="http://www.ja-sig.org/" target="_blank" title="{$token[@name='JASIG_LONG_LABEL']}"><xsl:value-of select="$token[@name='JASIG_LABEL']" /></a></li>
					<li><a href="http://www.uportal.org/" target="_blank" title="{$token[@name='UPORTAL_LONG_LABEL']}"><xsl:value-of select="$token[@name='UPORTAL_LABEL']" /></a></li>
					<li><a href="http://www.uportal.org/download.html" target="_blank" title="{$token[@name='UPORTAL_DOWNLOAD_LONG_LABEL']}"><xsl:value-of select="$token[@name='UPORTAL_DOWNLOAD_LABEL']" /></a></li>
					<li class="last"><a href="http://www.uportal.org/community/index.html" target="_blank" title="{$token[@name='UPORTAL_COMMUNITY_LONG_LABEL']}"><xsl:value-of select="$token[@name='UPORTAL_COMMUNITY_LABEL']" /></a></li>
				</ul>
				<div id="portal-version">
					<div id="portal-version-inner">
						<span><xsl:value-of select="$uP_productAndVersion" /></span>
					</div>
				</div>
			</div>
		</div>
	</xsl:template>
	

	<!-- ################################################################################# -->
    <!-- START WRAPPING FUNCTIONS -->

	<!-- ########### -->
    <!-- TAB_WRAPPER -->
	<!-- ########### -->
	<!-- 
	Used to insert any valid XML or XSL before, after tabs.  
	Can also iterate through tabs to wrap them with other elements (ul elements, for example).
	-->
	<xsl:template name="TAB_WRAPPER">
		<a name="tabNavigation"><xsl:comment>space</xsl:comment></a>
		<!-- TABS AS UL -->
		<ul>
	        <xsl:for-each select = "child::*">
	        	<xsl:variable name = "class">
		        	<xsl:choose>
                        <xsl:when test="(name()='inactiveTab') and (@firstColumnId != '')">portal-tab-inactive portlet-tab-inactive-target</xsl:when>
                        <xsl:when test="name()='inactiveTab'">portal-tab-inactive</xsl:when>
		        		<xsl:when test="name()='focusedTab'">portal-tab-focused</xsl:when>
		        		<xsl:when test="name()='selectedTab'">portal-tab-selected</xsl:when>
		        		<xsl:when test="name()='move_target'">portal-tab-move-target</xsl:when>
		        		<xsl:when test="name()='add_target'">portal-tab-move-target</xsl:when>
		        		<xsl:otherwise></xsl:otherwise>
		        	</xsl:choose>
	        	</xsl:variable>
		        <li tabId="{@ID}" firstColumnId="{@firstColumnId}" firstPortletId="{@firstPortletId}">
		        	<xsl:if test = "$class">
			        	<xsl:attribute  name = "class" ><xsl:value-of select="$class" /></xsl:attribute>
		        	</xsl:if>
			        <!--<span>
			        	<xsl:if test = "$class">
				        	<xsl:attribute  name = "class" ><xsl:value-of select="$class" />-inner</xsl:attribute>
			        	</xsl:if> -->
				        <xsl:apply-templates select=".">
				            <xsl:with-param name="type" select="'tab'"/>
				        </xsl:apply-templates>
			        <!--</span> -->
		        </li>
	        </xsl:for-each>
        </ul>
	
		<!-- TABS AS TABLE -->
		<!--
		<table cellspacing="5">
	        <tr valign="top">
	        <xsl:for-each select = "child::*">
	        	<xsl:variable name = "class">
		        	<xsl:choose>
		        		<xsl:when test="name()='inactiveTab'">portal-tab-inactive</xsl:when>
		        		<xsl:when test="name()='focusedTab'">portal-tab-focused</xsl:when>
		        		<xsl:when test="name()='selectedTab'">portal-tab-selected</xsl:when>
		        		<xsl:when test="name()='move_target'">portal-tab-move-target</xsl:when>
		        		<xsl:when test="name()='add_target'">portal-tab-move-target</xsl:when>
		        		<xsl:otherwise></xsl:otherwise>
		        	</xsl:choose>
	        	</xsl:variable>
		        <td>
		        	<xsl:if test = "$class">
			        	<xsl:attribute  name = "class" ><xsl:value-of select="$class" /></xsl:attribute>
		        	</xsl:if>
			        <div>
			        	<xsl:if test = "$class">
				        	<xsl:attribute  name = "class" ><xsl:value-of select="$class" />-inner</xsl:attribute>
			        	</xsl:if>
				        <xsl:apply-templates select=".">
				            <xsl:with-param name="type" select="'tab'"/>
				        </xsl:apply-templates>
			        </div>
		        </td>
	        </xsl:for-each>
	        </tr>
        </table> 
        -->        
	</xsl:template>


	<!-- ############### -->
    <!-- CONTENT_WRAPPER -->
	<!-- ############### -->
	<!-- 
	Used to insert any valid XML or XSL before, after columns content.  
	Can also iterate through columns to wrap them with other elements (table elements, for example).
	-->
	<xsl:template name="CONTENT_WRAPPER">
		<a name="startContent"><xsl:comment>Comment to keep from collapsing</xsl:comment></a>
		<!--
		<xsl:apply-templates>
            <xsl:with-param name="type" select="'column'"/>
        </xsl:apply-templates> 
        -->
        <h2 id="portal-page-title"><xsl:value-of select="../navigation/focusedTab/@name" /></h2>
        
        <div id="portal-columns-table-wrapper">
	        <table id="portal-columns-table" width="100%">
		        <tr valign="top">
		        <xsl:for-each select = "child::*">
		        	<td>
			        	<xsl:attribute  name = "width" >
							<xsl:choose>
								<!-- Narrow Column -->
								<xsl:when test="$USE_WIDE_NARROW_COLUMNS = 'true' and @width = $NARROW_COLUMN_WIDTH"><xsl:value-of select="$narrowWidth" />%</xsl:when>
								<!-- Wide Column -->
								<xsl:when test="$USE_WIDE_NARROW_COLUMNS = 'true' and @width != $NARROW_COLUMN_WIDTH"><xsl:value-of select="$wideWidth" />%</xsl:when>
								<!-- Otherwise use width attribute as a percentage -->
								<xsl:otherwise><xsl:value-of select="@width" /><xsl:if test = "number(@width) = @width">%</xsl:if></xsl:otherwise>
							</xsl:choose>			        	
			        	</xsl:attribute>
		        		<xsl:apply-templates select=".">
				            <xsl:with-param name="type" select="'column'"/>
				        </xsl:apply-templates>
		        	</td>
		        </xsl:for-each>
		        </tr>
	        </table>
        </div>
	
	</xsl:template>

	
	<!-- ############### -->
    <!-- PORTLET_CONTENT -->
	<!-- ############### -->
	<!-- 
	Used to optionally show portlet content.
	OPTIONS: Don't render if minimized, Don't render in Preferences mode, Both, Neither
	-->
	<xsl:template name="PORTLET_CONTENT">
        <!-- Don't render any content for a minimized channel -->
        <xsl:if test="@minimized != 'true' and not($isPreferences and not($isFocused))">
		    <div class="portlet-body">
		        <div class="portlet-body-inner">
			        <xsl:copy-of select="."/>
		        </div>
		    </div>
        </xsl:if>
        <xsl:if test = "$isPreferences and not($isFocused)">
		    <div class="portlet-body">
		        <div class="portlet-body-inner">
			        <div class="portlet-move-controls">
                        <xsl:variable name="portletDepth" select="count(preceding-sibling::*)+1"/>
			        	<div class="portlet-move-controls-inner">
			        		<!-- MOVE UP (if not 1st portlet in column) -->
							<xsl:choose>
								<xsl:when test="count(preceding-sibling::*) = 0">
							    	<div class="portlet-move-up"><img alt="{$token[@name='PORTLET_MOVE_UP_DISABLED_TITLE']}" title="{$token[@name='PORTLET_MOVE_UP_DISABLED_TITLE']}" src="{$mediaPathSkin}/cont_up_off.gif" /></div>
								</xsl:when>
								<xsl:otherwise>
							    	<div class="portlet-move-up"><a href="{$baseActionURL}?focusedTabID={$focusedTabID}&amp;mode={$mode}&amp;selectedID={@ID}&amp;targetAction=Channel%20Move&amp;targetNextID={preceding-sibling::*[1]/@ID}&amp;targetParentID={../@ID}&amp;targetRestriction=channel&amp;uP_cancel_targets=true&amp;uP_move_target={@ID}&amp;uP_sparam=focusedTabID&amp;uP_sparam=mode&amp;uP_sparam=selectedID&amp;uP_sparam=targetAction&amp;uP_sparam=targetRestriction" title="{$token[@name='PORTLET_MOVE_UP_TITLE']}"><img alt="{$token[@name='PORTLET_MOVE_UP_TITLE']}" src="{$mediaPathSkin}/cont_up_on.gif" /></a></div>
								</xsl:otherwise>
							</xsl:choose>
							<!-- MOVE LEFT (if not in 1st column) -->
							<xsl:choose>
								<xsl:when test="count(../preceding-sibling::*) = 0">
						        	<div class="portlet-move-left"><img title="{$token[@name='PORTLET_MOVE_LEFT_DISABLED_TITLE']}" alt="{$token[@name='PORTLET_MOVE_LEFT_DISABLED_TITLE']}" src="{$mediaPathSkin}/cont_left_off.gif" /></div>
								</xsl:when>
								<xsl:otherwise>
                                    <xsl:variable name="nextId">
                                        <xsl:choose>
                                            <xsl:when test="../preceding-sibling::*[1]/channel[$portletDepth]">
                                                <xsl:value-of select="../preceding-sibling::*[1]/channel[$portletDepth]/@ID"/>
                                            </xsl:when>
                                            <xsl:otherwise></xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:variable>
						        	<div class="portlet-move-left"><a href="{$baseActionURL}?focusedTabID={$focusedTabID}&amp;mode={$mode}&amp;selectedID={@ID}&amp;targetAction=Channel%20Move&amp;targetNextID={$nextId}&amp;targetParentID={../preceding-sibling::*[1]/@ID}&amp;targetRestriction=channel&amp;uP_cancel_targets=true&amp;uP_move_target={@ID}&amp;uP_sparam=focusedTabID&amp;uP_sparam=mode&amp;uP_sparam=selectedID&amp;uP_sparam=targetAction&amp;uP_sparam=targetRestriction" title="{$token[@name='PORTLET_MOVE_LEFT_TITLE']}"><img alt="{$token[@name='PORTLET_MOVE_LEFT_TITLE']}" src="{$mediaPathSkin}/cont_left_on.gif" /></a></div>
								</xsl:otherwise>
							</xsl:choose>
							<!-- MOVE RIGHT (if not in the last column) -->
							<xsl:choose>
								<xsl:when test="count(../following-sibling::*) = 0">
						        	<div class="portlet-move-right"><img title="{$token[@name='PORTLET_MOVE_RIGHT_DISABLED_TITLE']}" alt="{$token[@name='PORTLET_MOVE_RIGHT_DISABLED_TITLE']}" src="{$mediaPathSkin}/cont_right_off.gif" /></div>
								</xsl:when>
								<xsl:otherwise>
									<xsl:variable name = "targetID">
										<xsl:choose>
											<xsl:when test="../following-sibling::*[1]"><xsl:value-of select="../following-sibling::*[1]/@ID" /></xsl:when>
											<xsl:otherwise></xsl:otherwise>
										</xsl:choose>
									</xsl:variable>
                                    <xsl:variable name="nextId">
                                        <xsl:choose>
                                            <xsl:when test="../following-sibling::*[1]/channel[$portletDepth]">
                                                <xsl:value-of select="../following-sibling::*[1]/channel[$portletDepth]/@ID"/>
                                            </xsl:when>
                                            <xsl:otherwise></xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:variable>
						        	<div class="portlet-move-right"><a href="{$baseActionURL}?focusedTabID={$focusedTabID}&amp;mode={$mode}&amp;selectedID={@ID}&amp;targetAction=Channel%20Move&amp;targetNextID={$nextId}&amp;targetParentID={$targetID}&amp;targetRestriction=channel&amp;uP_cancel_targets=true&amp;uP_move_target={@ID}&amp;uP_sparam=focusedTabID&amp;uP_sparam=mode&amp;uP_sparam=selectedID&amp;uP_sparam=targetAction&amp;uP_sparam=targetRestriction" title="{$token[@name='PORTLET_MOVE_RIGHT_TITLE']}"><img alt="{$token[@name='PORTLET_MOVE_RIGHT_TITLE']}" src="{$mediaPathSkin}/cont_right_on.gif" /></a></div>
								</xsl:otherwise>
							</xsl:choose>
				        	<!-- MOVE DOWN (if not the last portlet in the column) -->
							<xsl:choose>
								<xsl:when test="count(following-sibling::*) = 0">
						        	<div class="portlet-move-down"><img alt="{$token[@name='PORTLET_MOVE_DOWN_DISABLED_TITLE']}" title="{$token[@name='PORTLET_MOVE_DOWN_DISABLED_TITLE']}" src="{$mediaPathSkin}/cont_down_off.gif" /></div>
								</xsl:when>
								<xsl:otherwise>
									<xsl:variable name = "targetID">
										<xsl:choose>
											<xsl:when test="following-sibling::*[2]"><xsl:value-of select="following-sibling::*[2]/@ID" /></xsl:when>
											<xsl:otherwise></xsl:otherwise>
										</xsl:choose>
									</xsl:variable>
							    	<div class="portlet-move-down"><a href="{$baseActionURL}?focusedTabID={$focusedTabID}&amp;mode={$mode}&amp;selectedID={@ID}&amp;targetAction=Channel%20Move&amp;targetNextID={$targetID}&amp;targetParentID={../@ID}&amp;targetRestriction=channel&amp;uP_cancel_targets=true&amp;uP_move_target={@ID}&amp;uP_sparam=focusedTabID&amp;uP_sparam=mode&amp;uP_sparam=selectedID&amp;uP_sparam=targetAction&amp;uP_sparam=targetRestriction" title="{$token[@name='PORTLET_MOVE_DOWN_TITLE']}"><img alt="{$token[@name='PORTLET_MOVE_DOWN_TITLE']}" src="{$mediaPathSkin}/cont_down_on.gif" /></a></div>
								</xsl:otherwise>
							</xsl:choose>
			        	</div>
			        </div>
	        	</div>
	        </div>
        </xsl:if>
	</xsl:template>	


	<!-- ####################### -->
    <!-- PORTLET_FOCUSED_CONTENT -->
	<!-- ####################### -->
	<!-- 
	Used to optionally show portlet content when focused.
	-->
	<xsl:template name="PORTLET_FOCUSED_CONTENT">
		<xsl:call-template name = "PORTLET_CONTENT" />	
	</xsl:template>	
	
	
	<!-- ##################### -->
    <!-- PORTLET_CONTROLS_AREA -->
	<!-- ##################### -->
	<!-- 
	Used to show portlet controls.
	OPTIONS: Don't render any controls, Wrap controls in table or ul (then use PORTLET_CONTROLS to wrap with td or li), ...
	-->
	<xsl:template name="PORTLET_CONTROLS_AREA">
        <ul><xsl:call-template name="channelRestrictions"/></ul>
	</xsl:template>	
	
    <!-- END WRAPPING FUNCTIONS -->
	<!-- ################################################################################# -->
	

	<!-- ######### -->
    <!-- TOP_BUTTONS -->
	<!-- ######### -->
	<!-- 
	Template used to render top links on the Page.
	-->
	<xsl:template name="TOP_BUTTONS">
		<xsl:param name="disabled">false</xsl:param>
		<xsl:param name="type" /><!-- See page.xsl for list of types -->
		<xsl:param name="url" /><!-- url to go to if selected -->
		<xsl:param name="class" /><!-- CSS class -->
		<xsl:param name="shortLabel" /><!-- short label, usually seen 1st -->
		<xsl:param name="longLabel" /><!-- long label, usually displayed on rollover or after short label -->
        <!--
        <a href="{$url}" title="{$longLabel}">
            <xsl:if test="$type = 'HOME' and not($mode='view')">
                <xsl:attribute name="onclick">return confirm('<xsl:value-of select="$token[@name='PREF_EXIT_CONFIRMATION']" />')</xsl:attribute>
            </xsl:if>
            <xsl:value-of select="$shortLabel" />
        </a> 
        -->
        <button title="{$longLabel}" type="submit">
        	<xsl:if test = "$disabled = 'true'">
        		<xsl:attribute  name = "disabled" >disabled</xsl:attribute>
        	</xsl:if>
        	<xsl:if test = "$class">
        		<xsl:attribute  name = "class" ><xsl:value-of select="$class" /><xsl:if test = "$disabled = 'true'">-disabled</xsl:if></xsl:attribute>
        	</xsl:if>
            <xsl:if test="$type = 'HOME' and not($mode='view')">
                <xsl:attribute name="onclick">return confirm('<xsl:value-of select="$token[@name='PREF_EXIT_CONFIRMATION']" />')</xsl:attribute>
            </xsl:if>
	       	<span><xsl:value-of select="$shortLabel" /></span>
        </button>
	</xsl:template>
	
	
	<!-- ############### -->
    <!-- COLUMN_CONTROLS -->
	<!-- ############### -->
	<!-- 
	Template used to render column controls in Preferences mode.
	-->
	<xsl:template name="COLUMN_CONTROLS">
		<xsl:param name="disabled">false</xsl:param>
		<xsl:param name="type" /><!-- See page.xsl for list of types -->
		<xsl:param name="url" /><!-- url to go to if selected -->
		<xsl:param name="class" /><!-- CSS class -->
		<xsl:param name="shortLabel" /><!-- short label, usually seen 1st -->
		<xsl:param name="longLabel" /><!-- long label, usually displayed on rollover or after short label -->
        <xsl:choose>
        	<xsl:when test="$disabled = 'true'">
        		<span title="{$longLabel}">
		        	<xsl:if test = "$class">
		        		<xsl:attribute  name = "class" ><xsl:value-of select="$class" /></xsl:attribute>
		        	</xsl:if>
        			<xsl:value-of select="$shortLabel" />
        		</span>
        	</xsl:when>
          
        	<xsl:otherwise>
	        	<a href="{$url}" title="{$longLabel}">
		        	<xsl:if test = "$class">
		        		<xsl:attribute  name = "class" ><xsl:value-of select="$class" /></xsl:attribute>
		        	</xsl:if>
		        	<xsl:if test = "$type = 'DELETE'">
		        		<xsl:attribute  name = "onclick" >return confirm('<xsl:value-of select="$token[@name='COLUMN_DELETE_CONFIRMATION']" />')</xsl:attribute>
		        	</xsl:if>
		            <xsl:value-of select="$shortLabel" />
		        </a>
        	</xsl:otherwise>
        </xsl:choose>
	</xsl:template>


	<!-- ################ -->
    <!-- PORTLET_CONTROLS -->
	<!-- ################ -->
	<!-- 
	Template used to render column controls in Preferences mode.
	-->
	<xsl:template name="PORTLET_CONTROLS">
		<xsl:param name="disabled">false</xsl:param>
		<xsl:param name="type" /><!-- See content.xsl for list of types -->
		<xsl:param name="url" /><!-- url to go to if selected -->
		<xsl:param name="class" /><!-- CSS class -->
		<xsl:param name="shortLabel" /><!-- short label, usually seen 1st -->
		<xsl:param name="longLabel" /><!-- long label, usually displayed on rollover or after short label -->
        
        <xsl:if test = "$type != 'MINIMIZE' and $type != 'UNMINIMIZE'">
        <li>
        <xsl:choose>
        	<xsl:when test="$disabled = 'true'">
        		<span title="{$longLabel}">
		        	<xsl:if test = "$class">
		        		<xsl:attribute  name = "class" ><xsl:value-of select="$class" />-disabled</xsl:attribute>
		        	</xsl:if>
        			<xsl:value-of select="$shortLabel" />
        		</span>
        	</xsl:when>
        	<xsl:otherwise>
	        	<a href="{$url}" title="{$longLabel}">
		        	<xsl:if test = "$class">
		        		<xsl:attribute  name = "class" ><xsl:value-of select="$class" /></xsl:attribute>
		        	</xsl:if>
		        	<xsl:if test = "$type = 'REMOVE'">
		        		<xsl:attribute  name = "onclick" >return confirm('<xsl:value-of select="$token[@name='PORTLET_REMOVE_CONFIRMATION']" />')</xsl:attribute>
		        	</xsl:if>
		        	<xsl:if test = "$type = 'DETACH'">
		        		<xsl:attribute  name = "target" >detachedWindow_<xsl:value-of select="@id" /></xsl:attribute>
		        		<xsl:attribute  name = "onclick" >openBrWindow('{$url}','detachedWindow_<xsl:value-of select="@id" />','toolbar=yes,location=yes,status=yes,menubar=yes,scrollbars=yes,resizable=yes,width=640,height=480'); return false;</xsl:attribute>
		        	</xsl:if>
		            <span><xsl:value-of select="$shortLabel" /></span>
		        </a>
        	</xsl:otherwise>
        </xsl:choose>
        </li>
        </xsl:if>
	</xsl:template>


	<!-- ############# -->
    <!-- PORTLET_TITLE -->
	<!-- ############# -->
	<!-- 
	Template used to render portlet title.
	-->	
	<xsl:template name="PORTLET_TITLE">
		<xsl:param name="title" />
        <xsl:choose>
        	<xsl:when test = "$isPreferences">
        		<span><xsl:value-of select="$title" /></span>
        	</xsl:when>
            <xsl:when test="@minimized='true'">
                <a class="portlet-title-unminimize-link" title="{$token[@name='PORTLET_UNMINIMIZE_LONG_LABEL']}">
                	<xsl:attribute  name = "href" ><xsl:value-of select="$baseActionURL" />?uP_tcattr=minimized&amp;minimized_channelId=<xsl:value-of select="@ID" />&amp;minimized_<xsl:value-of select="@ID" />_value=false#<xsl:value-of select="@ID" /></xsl:attribute>
                	<span><xsl:value-of select="$title" /></span>
                </a>
            </xsl:when>
            <xsl:otherwise>
                <a class="portlet-title-minimize-link" title="{$token[@name='PORTLET_MINIMIZE_LONG_LABEL']}">
                	<xsl:attribute  name = "href" ><xsl:value-of select="$baseActionURL" />?uP_tcattr=minimized&amp;minimized_channelId=<xsl:value-of select="@ID" />&amp;minimized_<xsl:value-of select="@ID" />_value=true#<xsl:value-of select="@ID" /></xsl:attribute>
                	<span><xsl:value-of select="$title" /></span>
                </a>
            </xsl:otherwise>
        </xsl:choose>
	</xsl:template>


	<!-- ##################### -->
    <!-- PORTLET_FOCUSED_TITLE -->
	<!-- ##################### -->
	<!-- 
	Template used to render portlet title when focused.
	-->	
	<xsl:template name="PORTLET_FOCUSED_TITLE">
		<xsl:param name="title" />
		<span><xsl:value-of select="$title" /></span>
	</xsl:template>
	
	
	<!-- ################################################################################# -->
    <!-- START DETACHED FUNCTIONS -->

	<!-- ############# -->
    <!-- DETACHED_HEAD -->
	<!-- ############# -->
	<!-- 
	Used to insert any valid XML or XSL into the head of the HTML document <head />, 
	specifically <link />'s, <script />'s, <style />'s, and <meta />'s 
	-->
    <xsl:template name="DETACHED_HEAD">
        <xsl:call-template name = "HEAD" /><!-- Use same template for now -->
    </xsl:template>	


	<!-- ################### -->
    <!-- DETACHED_BODY_START -->
	<!-- ################### -->
	<!-- 
	Used to insert any valid XML or XSL into the HTML document <body />, 
	before any other content (detached channel only)
	-->
    <xsl:template name="DETACHED_BODY_START"></xsl:template>	


	<!-- ################# -->
    <!-- DETACHED_BODY_END -->
	<!-- ################# -->
	<!-- 
	Used to insert any valid XML or XSL into the HTML document <body />, 
	after all other content (detached channel only)
	-->
    <xsl:template name="DETACHED_BODY_END"></xsl:template>	

    <!-- END DETACHED FUNCTIONS -->
	<!-- ################################################################################# -->

		
</xsl:stylesheet>
