<?xml version="1.0"?>
<!--
 | Copyright 2006 The JA-SIG Collaborative.  All rights reserved.
 | See license distributed with this file and
 | available online at http://www.uportal.org/license.html
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<!-- ################################################################################# -->
    <!--                                    CONTENT                                        -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!--
	<content>
      <column ... > ... </column>
      <column ... >	... </column>
   </content>
	-->
    <xsl:template match="content">
        <div id="portal-main-content">
            <div id="portal-main-content-inner">
                <xsl:call-template name = "CONTENT_WRAPPER" />
            </div>
        </div>
    </xsl:template>


	<!-- ################################################################################# -->
    <!--                                CHANNEL (PORTLET)                                  -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!--
	<channel ID="a25" editable="false" hasAbout="false" hasHelp="false" hidden="false" immutable="false" name="GroupsManager" portletWindowId="14" title="Groups Manager" unremovable="false" minimized="false" />
	-->
    <xsl:template match="channel">
    	<xsl:variable name = "title">
    		<xsl:choose>
    			<xsl:when test="@title"><xsl:value-of select="@title" /></xsl:when>
    			<xsl:otherwise><xsl:value-of select="@name" /></xsl:otherwise>
    		</xsl:choose>
    	</xsl:variable>
        <!-- Begin Channel Table -->
        <xsl:variable name = "class">
    		<xsl:choose>
    			<xsl:when test="../@immutable='true'">portal-portlet portal-portlet-<xsl:value-of select="@name" /></xsl:when>
    			<xsl:otherwise>portal-portlet portal-portlet-<xsl:value-of select="@name"/> portlet-movable</xsl:otherwise>
    		</xsl:choose>
    	</xsl:variable>
        <div class="{$class}" id="{@ID}">
	        <div class="portal-portlet-inner">
		        <div class="portlet-head">
			        <div class="portlet-head-inner">
				        <xsl:choose>
				            <xsl:when test="$selectedID=@ID">
				                <div class="portlet-title-selected">
				                    <div class="portlet-title-selected-inner">
				                        <span class="uportal-channel-title">
				                            <a name="{@ID}"><xsl:value-of select="$title"/></a>
				                            <xsl:value-of select="$token[@name='PORTLET_SELECTED']" />
				                        </span>
				                    </div>
				                </div>
				            </xsl:when>
				            <xsl:otherwise>
				                <div class="portlet-title">
				                    <div class="portlet-title-inner">
			                            <a name="{@ID}"><xsl:comment>Comment to keep from collapse</xsl:comment></a>
			                            <xsl:call-template name = "PORTLET_TITLE" >
			                            	<xsl:with-param name="title"><xsl:value-of select="$title"/></xsl:with-param>
			                            </xsl:call-template>
				                    </div>
				                </div>
				            </xsl:otherwise>
				        </xsl:choose>
				        <div class="portlet-controls">
				            <div class="portlet-controls-inner">
				                <xsl:call-template name="PORTLET_CONTROLS_AREA"/>
				            </div>
				        </div>
			        </div>
		        </div>
                <xsl:call-template name = "PORTLET_CONTENT" />
	        </div>
        </div>
        <!-- End Channel Table -->
    </xsl:template>
    
    <!-- Focused Channel/Portlet -->
    <xsl:template match="focusedContent/channel|focusedContent/sitemap">
    	<xsl:variable name = "title">
    		<xsl:choose>
    			<xsl:when test="name(.)='sitemap'">Site Map</xsl:when>
    			<xsl:when test="@title"><xsl:value-of select="@title" /></xsl:when>
    			<xsl:otherwise><xsl:value-of select="@name" /></xsl:otherwise>
    		</xsl:choose>
    	</xsl:variable>
        <div class="portal-portlet-focused portal-portlet-{@name}">
	        <div class="portal-portlet-focused-inner">
		        <div class="portlet-head">
			        <div class="portlet-head-inner">
		                <div class="portlet-title">
		                    <div class="portlet-title-inner">
	                            <a name="{@ID}"><xsl:comment>Comment to keep from collapse</xsl:comment></a>
	                            <xsl:call-template name = "PORTLET_FOCUSED_TITLE" >
	                            	<xsl:with-param name="title"><xsl:value-of select="$title"/></xsl:with-param>
	                            </xsl:call-template>
				            </div>
				        </div>
			        </div>
		        </div>
		        <div class="portlet-body">
		            <div class="portlet-body-inner">
		                <xsl:choose>
		                	<xsl:when test="name(.)='sitemap'">
		                		<ul class="portal-sitemap"><xsl:apply-templates /></ul>
		                	</xsl:when>
		                  
		                	<xsl:otherwise>
			                	<xsl:call-template name = "PORTLET_FOCUSED_CONTENT" />
		                	</xsl:otherwise>
		                </xsl:choose>
		            </div>
		        </div>
	        </div>
        </div>
    	
    </xsl:template>


	<xsl:template match="tab">
		<li class="portal-sitemap-tab">
			<a href="{$baseActionURL}?uP_sparam=focusedTabID&amp;focusedTabID={@ID}&amp;uP_sparam=mode&amp;mode={$mode}&amp;uP_sparam=viewSiteMap&amp;viewSiteMap=" title="{$token[@name='FOCUS_TAB_LABEL']}"><span><xsl:value-of select="@title" /></span></a>
			<xsl:if test = "count(portlet) &gt; 0">
				<ul>
					<xsl:apply-templates />
				</ul>
			</xsl:if>
		</li>
	</xsl:template>
	
	
	<xsl:template match="portlet">
		<xsl:variable name = "title">
			<xsl:choose>
				<xsl:when test="@title != ''"><xsl:value-of select="@title" /></xsl:when>
			  
				<xsl:otherwise><xsl:value-of select="@name" /></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<li class="portal-sitemap-portlet">
			<a href="{$baseActionURL}?uP_root={@ID}&amp;uP_sparam=viewSiteMap&amp;viewSiteMap=" title="{$token[@name='PORTLET_MAXIMIZE_LONG_LABEL']}"><span><xsl:value-of select="$title" /></span></a>
		</li>
	</xsl:template>	


	<!-- ####################### -->
    <!-- NORMAL CHANNEL CONTROLS -->
	<!-- ####################### -->
    <xsl:template name="channelRestrictions">
        <xsl:choose>
            <xsl:when test="$mode='preferences' and $userLayoutRoot='root'">
                <!-- Conditionals for Preferences Mode -->
                <xsl:choose>
                    <xsl:when test="$selectedID=@ID and $targetAction='Channel Move'">
                        <xsl:call-template name="channel.action.cancelMove"/>
                    </xsl:when>
                    <xsl:when test="not(../@immutable='false')">
                        <xsl:call-template name="channel.action.moveLocked"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="channel.action.requestMoveTargets"/>
                    </xsl:otherwise>
                </xsl:choose>
                <!-- Language preferences removed until later version of uPortal -->
                <xsl:choose>
                    <xsl:when test="not(../@immutable='false') or not(../@unremovable='false')">
                        <xsl:call-template name="channel.action.removeLocked"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="channel.action.remove"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="not($userLayoutRoot='root')">
                <!-- <xsl:call-template name="focusedControls"/> -->
                <xsl:call-template name="channel.action.root"/>
                <xsl:if test="not(@hasHelp='false')">
                    <xsl:call-template name="channel.action.help"/>
                </xsl:if>
                <xsl:if test="not(@hasAbout='false')">
                    <xsl:call-template name="channel.action.about"/>
                </xsl:if>
                <xsl:if test="not(@editable='false')">
                    <xsl:call-template name="channel.action.edit"/>
                </xsl:if>
                <xsl:if test="@printable='true'">
                    <xsl:call-template name="channel.action.print"/>
                </xsl:if>
            </xsl:when>
            <xsl:otherwise>
                <!-- <xsl:call-template name="controls"/> -->
                <xsl:if test="not(@hasHelp='false')">
                    <xsl:call-template name="channel.action.help"/>
                </xsl:if>
                <xsl:if test="not(@hasAbout='false')">
                    <xsl:call-template name="channel.action.about"/>
                </xsl:if>
                <xsl:if test="not(@editable='false')">
                    <xsl:call-template name="channel.action.edit"/>
                </xsl:if>
                <xsl:if test="@printable='true'">
                    <xsl:call-template name="channel.action.print"/>
                </xsl:if>
                <xsl:call-template name="channel.action.focus"/>
                <xsl:choose>
                    <xsl:when test="@minimized='true'">
                        <xsl:call-template name="channel.action.unminimize"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="channel.action.minimize"/>
                    </xsl:otherwise>
                </xsl:choose>
                <!-- Detach is not currently implemented -->
                <!--<xsl:call-template name="channel.action.detach"/> -->
                <xsl:choose>
                    <xsl:when test="not(../@immutable='false') or not(../@unremovable='false')">
                        <xsl:call-template name="channel.action.removeLocked"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="channel.action.remove"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- END RESTRICTIONS -->

    
	<!-- ################################################################################# -->
    <!--                                FOCUSED CONTENT                                    -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!--
	<focusedContent>
		<channel ... />
	</focusedContent>
   	-->
    <xsl:template match="focusedContent">
        <div id="portal-main-content-focused">
            <div id="portal-main-content-focused-inner">
				<div id="portal-focused-controls">
					<div id="portal-focused-controls-inner">
						<a title="{$token[@name='BACK_HOME_TITLE_LONG_LABEL']}" href="{$baseActionURL}?uP_root=root&amp;uP_reload_layout=true&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true&amp;uP_sparam=mode&amp;mode={$mode}&amp;uP_sparam=viewSiteMap&amp;viewSiteMap=">
							<span><xsl:value-of select="$token[@name='BACK_HOME_TITLE_LABEL']" /></span>
						</a>
					</div>
				</div>
				<xsl:apply-templates />
			</div>
		</div>
    </xsl:template>

	<!-- ####################### -->
    <!-- DETACH CHANNEL CONTROLS -->
	<!-- ####################### -->
    <xsl:template name="detachedChannelControls">
        <xsl:if test="not(@hasHelp='false')">
            <xsl:call-template name="channel.action.help"/>
        </xsl:if>
        <xsl:if test="not(@hasAbout='false')">
            <xsl:call-template name="channel.action.about"/>
        </xsl:if>
        <xsl:if test="not(@editable='false')">
            <xsl:call-template name="channel.action.edit"/>
        </xsl:if>
        <xsl:if test="@printable='true'">
            <xsl:call-template name="channel.action.print"/>
        </xsl:if>
    </xsl:template>


	<!-- ################################################################################# -->
    <!-- START CHANNEL CONTROLS -->


	<!-- ###### -->
    <!-- REMOVE -->
	<!-- ####### -->
    <xsl:template name="channel.action.remove">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">REMOVE</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_remove_target=<xsl:value-of select="@ID" /></xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-remove-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_REMOVE_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_REMOVE_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- ############# -->
    <!-- REMOVE LOCKED -->
	<!-- ############# -->
    <xsl:template name="channel.action.removeLocked">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">REMOVE</xsl:with-param>
    		<xsl:with-param name="disabled">true</xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-remove-disabled-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_REMOVE_DISABLED_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_REMOVE_DISABLED_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- ########### -->
    <!-- CANCEL MOVE -->
	<!-- ########### -->
    <xsl:template name="channel.action.cancelMove">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">CANCEL</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_sparam=mode&amp;mode=<xsl:value-of select="$mode" />&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true</xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-move-cancel-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_MOVE_CANCEL_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_MOVE_CANCEL_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- #################### -->
    <!-- REQUEST MOVE TARGETS -->
	<!-- #################### -->
    <xsl:template name="channel.action.requestMoveTargets">
    	<xsl:if test = "$USE_CONTENT_AUTO_MOVE != 'true'">
	    	<xsl:call-template name = "PORTLET_CONTROLS" >
	    		<xsl:with-param name="type">MOVE</xsl:with-param>
	    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_request_move_targets=<xsl:value-of select="@ID" />&amp;uP_sparam=mode&amp;mode=<xsl:value-of select="$mode" />&amp;uP_sparam=selectedID&amp;selectedID=<xsl:value-of select="@ID" />&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=targetRestriction&amp;targetRestriction=channel&amp;uP_sparam=targetAction&amp;targetAction=Channel Move</xsl:with-param>
	    		<xsl:with-param name="class">portlet-controls-move-link</xsl:with-param>
	    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_MOVE_LABEL']" />
	    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_MOVE_LONG_LABEL']" />
	    	</xsl:call-template>
    	</xsl:if>
    </xsl:template>
    

	<!-- ########### -->
    <!-- MOVE LOCKED -->
	<!-- ########### -->
    <xsl:template name="channel.action.moveLocked">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">MOVE</xsl:with-param>
    		<xsl:with-param name="disabled">true</xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-move-disabled-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_MOVE_DISABLED_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_MOVE_DISABLED_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- ##### -->
    <!-- ABOUT -->
	<!-- ##### -->
    <xsl:template name="channel.action.about">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">ABOUT</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_about_target=<xsl:value-of select="@ID" />#<xsl:value-of select="@ID" /></xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-about-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_ABOUT_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_ABOUT_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- ##################### -->
    <!-- ROOT (Return to root) -->
	<!-- ##################### -->
    <xsl:template name="channel.action.root">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">ROOT</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_root=root</xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-return-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_RETURN_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_RETURN_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- #### -->
    <!-- HELP -->
	<!-- #### -->
    <xsl:template name="channel.action.help">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">HELP</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_help_target=<xsl:value-of select="@ID" />#<xsl:value-of select="@ID" /></xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-help-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_HELP_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_HELP_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- #### -->
    <!-- EDIT -->
	<!-- #### -->
    <xsl:template name="channel.action.edit">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">EDIT</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_edit_target=<xsl:value-of select="@ID" />#<xsl:value-of select="@ID" /></xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-edit-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_EDIT_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_EDIT_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- ##### -->
    <!-- PRINT -->
	<!-- ##### -->
    <xsl:template name="channel.action.print">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">PRINT</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_print_target=<xsl:value-of select="@ID" />#<xsl:value-of select="@ID" /></xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-print-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_PRINT_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_PRINT_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- ################ -->
    <!-- FOCUS (MAXIMIZE) -->
	<!-- ################ -->
    <xsl:template name="channel.action.focus">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">MAXIMIZE</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_root=<xsl:value-of select="@ID" /></xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-maximize-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_MAXIMIZE_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_MAXIMIZE_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- ########## -->
    <!-- UNMINIMIZE -->
	<!-- ########## -->
    <xsl:template name="channel.action.unminimize">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">UNMINIMIZE</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_tcattr=minimized&amp;minimized_channelId=<xsl:value-of select="@ID" />&amp;minimized_<xsl:value-of select="@ID" />_value=false#<xsl:value-of select="@ID" /></xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-unminimize-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_UNMINIMIZE_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_UNMINIMIZE_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>
    
    
	<!-- ######## -->
    <!-- MINIMIZE -->
	<!-- ######## -->
    <xsl:template name="channel.action.minimize">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">MINIMIZE</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_tcattr=minimized&amp;minimized_channelId=<xsl:value-of select="@ID" />&amp;minimized_<xsl:value-of select="@ID" />_value=true#<xsl:value-of select="@ID" /></xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-minimize-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_MINIMIZE_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_MINIMIZE_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>

    
	<!-- ###### -->
    <!-- DETACH -->
	<!-- ###### -->
    <xsl:template name="channel.action.detach">
    	<xsl:call-template name = "PORTLET_CONTROLS" >
    		<xsl:with-param name="type">DETACH</xsl:with-param>
    		<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_detach_target=<xsl:value-of select="@ID" /></xsl:with-param>
    		<xsl:with-param name="class">portlet-controls-detach-link</xsl:with-param>
    		<xsl:with-param name="shortLabel" select="$token[@name='PORTLET_DETACH_LABEL']" />
    		<xsl:with-param name="longLabel" select="$token[@name='PORTLET_DETACH_LONG_LABEL']" />
    	</xsl:call-template>
    </xsl:template>


    <!-- END CHANNEL CONTROLS -->
	<!-- ################################################################################# -->

	
</xsl:stylesheet>
