<?xml version="1.0" encoding="utf-8"?>
<!--
 | Copyright 2006 The JA-SIG Collaborative.  All rights reserved.
 | See license distributed with this file and
 | available online at http://www.uportal.org/license.html
-->


<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href = "config.xsl" /><!-- Configuration File (expected to be customized by institution) -->
	<xsl:import href = "page.xsl" /><!-- templates for page structure -->
	<xsl:import href = "tabs.xsl" /><!-- templates for tab structure -->
	<xsl:import href = "columns.xsl" /><!-- templates for column structure -->
	<xsl:import href = "content.xsl" /><!-- templates for content structure (i.e. portlets) -->
	<xsl:import href = "preferences.xsl" /><!-- templates for preferences specific structures -->
	
    <xsl:output method="xml" indent="no" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" omit-xml-declaration="yes" />
   
    <!-- PARAMETERS -->

    <!--These are used in all modes-->
    <xsl:param name="authorizedChannelPublisher">false</xsl:param>
    <xsl:param name="baseActionURL">render.userLayoutRootNode.uP</xsl:param>
    <xsl:param name="contextPath">CONTEXT_PATH_NOT_PASSED</xsl:param>
    <xsl:param name="errorMessage">no errorMessage passed</xsl:param>
    <xsl:param name="skin">uPbase</xsl:param>

    <xsl:param name="uP_productAndVersion">uPortal X.X.X</xsl:param>
    <xsl:param name="userName">Guest</xsl:param>
    
    <!-- NEW PARAMETERS-->
    <!-- These are used for localization -->
    <xsl:param name="messageDocURL">messages.xml</xsl:param>
    <xsl:param name="userLang">en</xsl:param>

    <!--These are used in preferences mode-->
    <xsl:param name="moveID" select="/layout/@selectedID"/>
    <xsl:param name="selectedID" select="/layout/@selectedID"/>
    <xsl:param name="focusedTabID" select="/layout/@focusedTabID"/>
    <xsl:param name="targetRestriction" select="/layout/@targetRestriction"/>
    <xsl:param name="targetAction" select="/layout/@targetAction"/>
    <xsl:param name="channelPublishID">no channelPublishID passed</xsl:param>

    <!-- VARIABLES -->

    <!--These are used in all modes-->
    <xsl:variable name="authenticated" select="/layout/@authenticated"/>
    <xsl:variable name="current_structure" select="/layout/@current_structure"/>
    <xsl:variable name="pathToPortlets" select="concat($contextPath,'/media/org/jasig/portal/portlets')"/>
    <xsl:variable name="mediaPath" select="concat($contextPath,'/uP2/media/org/jasig/portal/layout/Base_TabColumn/integratedModes')"/>
    <xsl:variable name="mediaPathSkin" select="concat($mediaPath,'/',$skin)"/>
    <xsl:variable name="mode" select="/layout/@mode"/>
    
    <!-- NEW VARIABLES-->
    <!-- This is used for localization of messages/text within the theme -->
    <xsl:variable name = "token" select = "document($messageDocURL)/theme-messages/tokens[lang($userLang)]/token" />
    <!-- These are used for ease of determining the what render "mode" the theme is in -->
    <xsl:variable name = "isPreferences" select = "boolean(/layout/@mode='preferences')" />
    <xsl:variable name = "isFocused" select = "boolean(/layout/focusedContent)" />
    <xsl:variable name = "isSiteMap" select = "boolean(//sitemap)" />
    <!-- This is used to add a suffix to certain CSS classes if unauthenticated -->
    <xsl:variable name = "unauthenticatedClassSuffix"><xsl:if test = "/layout[@authenticated != 'true']">-unauthenticated</xsl:if></xsl:variable>

    <!--These are used in preferences mode-->
    <xsl:variable name="userLayoutRoot" select="/layout/@userLayoutRoot"/>

	<!-- Width variables for wide/narrow values -->
	<xsl:variable name = "numOfCols" select = "count(//column)" />
	<xsl:variable name = "numOfNarrowCols" select = "count(//column[@width=$NARROW_COLUMN_WIDTH])" />
	<xsl:variable name = "numOfWideCols" select = "$numOfCols - $numOfNarrowCols" />
	<xsl:variable name = "avgColWidth" select = "round(100 div $numOfCols)" />
	<xsl:variable name = "wideWidth"><xsl:choose>
		<!-- If the average column width is less than the defined narrow width, then setting the wide width 5% 
			 more than the average width.
		 -->
		<xsl:when test="$avgColWidth &lt; $NARROW_COLUMN_WIDTH"><xsl:value-of select="$avgColWidth + 5" /></xsl:when>
	  	<!-- Otherwise calculate value of wide by taking 100%, subtract narrow columns and their widths, and divide remaining among the rest -->
		<xsl:otherwise><xsl:value-of select="round((100 - $numOfNarrowCols * $NARROW_COLUMN_WIDTH) div $numOfWideCols)" /></xsl:otherwise></xsl:choose>
	</xsl:variable>
	<xsl:variable name = "narrowWidth"><xsl:choose>
		<!-- If the average column width is less than the defined narrow width, then calculate a new narrow width by taking 100% 
			 and subtracting out the wide column widths, then dividing the remaining equally among the narrow columns.
		 -->
       	<xsl:when test="$avgColWidth &lt; $NARROW_COLUMN_WIDTH"><xsl:value-of select="round((100 - $numOfWideCols * $wideWidth) div $numOfNarrowCols)" /></xsl:when>
        <!-- Otherwise use narrow column width, as is -->
       	<xsl:otherwise><xsl:value-of select="$NARROW_COLUMN_WIDTH" /></xsl:otherwise></xsl:choose></xsl:variable>
   
    <!-- BEGIN RENDERING HERE -->
    <!-- Default match to either do redirect or continue rendering -->
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="$USE_TAB_AUTO_MOVE = 'true' and $targetAction = 'Tab Move'">
				<xsl:call-template name = "redirectHtml" >
					<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_move_target=&amp;targetNextID=&amp;targetParentID=userLayoutRootNode&amp;uP_sparam=mode&amp;mode=<xsl:value-of select="$mode" />&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=targetRestriction&amp;targetRestriction=no%20targetRestriction%20parameter&amp;uP_sparam=targetAction&amp;targetAction=no%20targetAction%20parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$USE_COLUMN_AUTO_MOVE = 'true' and $targetAction = 'Column Move'">
				<xsl:call-template name = "redirectHtml" >
					<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_sparam=mode&amp;mode=<xsl:value-of select="$mode" />&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$USE_CONTENT_AUTO_MOVE = 'true' and $targetAction = 'Channel Move'">
				<xsl:call-template name = "redirectHtml" >
					<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_sparam=mode&amp;mode=<xsl:value-of select="$mode" />&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test = "$USE_TAB_AUTO_ADD = 'true' and $targetRestriction='tab' and //add_target">
				<xsl:call-template name = "redirectHtml" >
					<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_add_target=folder&amp;targetNextID=&amp;targetParentID=userLayoutRootNode&amp;uP_sparam=mode&amp;mode=<xsl:value-of select="$mode" />&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_cancel_targets=true&amp;uP_sparam=newNodeID&amp;newNodeID=</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test = "$USE_COLUMN_AUTO_ADD = 'true' and $targetRestriction='column' and //add_target">
				<xsl:call-template name = "redirectHtml" >
					<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_add_target=folder&amp;targetNextID=&amp;targetParentID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=mode&amp;mode=<xsl:value-of select="$mode" />&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true&amp;uP_sparam=newNodeID&amp;newNodeID=</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test = "$USE_CONTENT_AUTO_ADD = 'true' and $targetRestriction='channel' and //add_target">
				<xsl:variable name = "addLocation" select = "//add_target[1]" />
				<xsl:call-template name = "redirectHtml" >
					<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_add_target=channel&amp;targetNextID=<xsl:value-of select="$addLocation/@nextID" />&amp;targetParentID=<xsl:value-of select="$addLocation/@parentID" />&amp;uP_sparam=mode&amp;mode=<xsl:value-of select="$mode" />&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true&amp;uP_sparam=newNodeID&amp;newNodeID=</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test = "$USE_CONTENT_AUTO_ADD = 'true' and $targetRestriction='channel' and not(//add_target)">
				<xsl:call-template name = "redirectHtml" >
					<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_sparam=mode&amp;mode=<xsl:value-of select="$mode" />&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates />
			</xsl:otherwise>
		</xsl:choose>
		
    	<!--<textarea name="structure">
    		<xsl:copy-of select = "//structure/params"/>
    		<xsl:apply-templates select="//structure/*[name(.) != 'params']" mode="debug" />
    	</textarea> -->
        <!--<textarea name="theme">
        	<params>
        		<param name="uP_productAndVersion"><xsl:value-of select="$uP_productAndVersion" /></param>
        		<param name="baseActionURL"><xsl:value-of select="$baseActionURL" /></param>
        		<param name="contextPath"><xsl:value-of select="$contextPath" /></param>
        		<param name="skin"><xsl:value-of select="$skin" /></param>
        		<param name="errorMessage"><xsl:value-of select="$errorMessage" /></param>
        		<param name="authorizedChannelPublisher"><xsl:value-of select="$authorizedChannelPublisher" /></param>
        		<param name="userName"><xsl:value-of select="$userName" /></param>
        		<param name="moveID"><xsl:value-of select="$moveID" /></param>
        		<param name="selectedID"><xsl:value-of select="$selectedID" /></param>
        		<param name="focusedTabID"><xsl:value-of select="$focusedTabID" /></param>
        		<param name="targetRestriction"><xsl:value-of select="$targetRestriction" /></param>
        		<param name="targetAction"><xsl:value-of select="$targetAction" /></param>
        		<param name="channelPublishID"><xsl:value-of select="$channelPublishID" /></param>
        	</params>
            <xsl:apply-templates mode="debug" />
        </textarea> -->
		
	</xsl:template>

	<!-- Template for converting XML input into debug form for outputing -->
    <xsl:template match="node()" mode="debug">
        <debug tagname="{name(.)}">
            <xsl:copy-of select="@*" />
            <xsl:apply-templates mode="debug"/>
        </debug>
    </xsl:template>

    <!-- REDIRECT HTML -->
	<!-- This template is called from the redirect template above, and defines a blank page which uses javascript to auto-submit a url that is passed along in the url param. -->
    <xsl:template name="redirectHtml">
        <xsl:param name="url"/>
        <html>
            <head>
				<meta http-equiv="refresh" content="1; URL={$url}" />
                <!--<script language="JavaScript">
                    location.replace('<xsl:value-of select="$url"/>');
                </script> -->
            </head>
            <body><xsl:comment>Page Body is Empty</xsl:comment></body>
        </html>
    </xsl:template>

</xsl:stylesheet>
