<?xml version="1.0"?>
<!--
 | Copyright 2006 The JA-SIG Collaborative.  All rights reserved.
 | See license distributed with this file and
 | available online at http://www.uportal.org/license.html
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	
	<!-- ################################################################################# -->
    <!--                                  NORMAL PAGE LAYOUT                               -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!--
	<layout userLayoutRoot="root" targetAction="no targetAction parameter" targetRestriction="no targetRestriction parameter" focusedTabID="a23" selectedID="" mode="view" lastSessionTabID="no lastSessionTabID parameter" immutable="false" unremovable="true" current_structure="layout" authenticated="true">
	   <header />
	   <navigation> ... </navigation>
	   <content> ... </content>
	   <footer />
	</layout>
	 -->
    <xsl:template match="layout">
    	<html>
            <head>
                <title><xsl:value-of select="$PAGE_TITLE"/></title>
                <xsl:call-template name="HEAD"/>
            </head>
            <body id="portal-normal{$unauthenticatedClassSuffix}">
            	<xsl:call-template name = "BODY_START" />
                <div id="portal-page"><xsl:apply-templates/></div>
            	<xsl:call-template name = "BODY_END" />
            </body>
        </html>
    </xsl:template>
    
    
	<!-- ################################################################################# -->
    <!--                                FOCUSED PORTLET LAYOUT                             -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!-- 
	<layout userLayoutRoot="a29" targetAction="no targetAction parameter" targetRestriction="no targetRestriction parameter" focusedTabID="a23" selectedID="" mode="view" lastSessionTabID="no lastSessionTabID parameter" immutable="false" unremovable="true" current_structure="layout" authenticated="true">
	   <header />
	
	   <focusedContent>
	      <channel ... />
	   </focusedContent>
	
	   <footer />
	</layout>        		
	-->
    <xsl:template match="layout[focusedContent]">
    	<html>
            <head>
                <title><xsl:value-of select="$PAGE_TITLE_FOCUSED"/></title>
                <xsl:call-template name="HEAD"/>
            </head>
            <body id="portal-focused{$unauthenticatedClassSuffix}">
            	<xsl:call-template name = "BODY_START_FOCUSED" />
                <div id="portal-page"><xsl:apply-templates/></div>
            	<xsl:call-template name = "BODY_END_FOCUSED" />
            </body>
        </html>
    </xsl:template>
    
    
	<!-- ################################################################################# -->
    <!--                               PREFERENCES LAYOUT                                  -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!-- 
	<layout userLayoutRoot="root" targetAction="no targetAction parameter" targetRestriction="no targetRestriction parameter" focusedTabID="a23" selectedID="" mode="preferences" lastSessionTabID="no lastSessionTabID parameter" immutable="false" unremovable="true" current_structure="layout" authenticated="true">
	   <header />
	   <navigation> ... </navigation>
	   <content> ... </content>
	   <footer />
	</layout>
	-->
    <xsl:template match="layout[$isPreferences]">
    	<html>
            <head>
                <title><xsl:value-of select="$PAGE_TITLE_PREFERENCES"/></title>
                <xsl:call-template name="HEAD"/>
            </head>
            <body id="portal-preferences{$unauthenticatedClassSuffix}">
            	<xsl:call-template name = "BODY_START_PREFERENCES" />
                <div id="portal-page"><xsl:apply-templates/></div>
            	<xsl:call-template name = "BODY_END_PREFERENCES" />
            </body>
        </html>
    </xsl:template>
	

	<!-- ################################################################################# -->
    <!--                                  MESSAGE PAGE LAYOUT                              -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!--
	<layout userLayoutRoot="root" targetAction="no targetAction parameter" targetRestriction="channel" focusedTabID="a23" selectedID="" mode="view" lastSessionTabID="no lastSessionTabID parameter" immutable="false" unremovable="true" current_structure="layout" authenticated="true">
	   <header />
	   <navigation> ... </navigation>
	   <content> ... </content>
	   <footer />
	</layout>
	 -->
    <!--<xsl:template match="layout[$USE_CONTENT_AUTO_ADD = 'true' and $targetRestriction='channel' and not(//add_target)]">
    	<html>
            <head>
                <title><xsl:value-of select="$PAGE_TITLE"/></title>
                <xsl:call-template name="HEAD"/>
            </head>
            <body id="portal-message{$unauthenticatedClassSuffix}">
                <div id="portal-page">
                	<div id="portal-message-text">
                		<p><xsl:value-of select="$token[@name='MESSAGE_CONTENT_ADD_FAILED']" /></p>
                		<form>
                			<button><span>OK</span></button>
                		</form>
                	</div>
                </div>
            </body>
        </html>
    </xsl:template> -->
    
    
	<!-- ################################################################################# -->
    <!--                              DETACHED PAGE LAYOUT                                 -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!--
	
	 -->
    <!--  Used for detached content  -->
    <xsl:template match="layout_fragment">
        <html>
            <head>
                <title>
                    <xsl:value-of select="$DETACHED_PAGE_TITLE"/>
                </title>
                <xsl:call-template name="DETACHED_HEAD"/>
            </head>
            <body id="portal-detached{$unauthenticatedClassSuffix}">
                <div id="portal-page">
                    <xsl:apply-templates select="content//channel">
                        <xsl:with-param name="detachedContent" select="'true'"/>
                    </xsl:apply-templates>
                </div>
            </body>
        </html>
    </xsl:template>


	<!-- ################################################################################# -->
    <!--                                    HEADER                                         -->
	<!-- ################################################################################# -->	
	<!-- SAMPLE XML -->
	<!--
	<header />
	 -->
    <xsl:template match="header">
        <!-- BEGIN: Masthead and Header Channel -->
        <div id="portal-header">
            <div id="portal-header-inner">
                <xsl:call-template name = "MAIN_LOGO" />
                <!--BEGIN: Temporary Header Channel: Home,SiteMap,Prefs,Logout -->
                <xsl:if test="$authenticated='true' ">
                    <div id="portal-main-links">
                        <div id="portal-main-links-inner">
                            <ul>
                                <li class="first">
                                	<xsl:choose>
                                		<xsl:when test="$isFocused">
                                			<form action="{$baseActionURL}" method="get">
												<input type="hidden" name="uP_root" value="root" />
												<input type="hidden" name="uP_reload_layout" value="true" />
												<input type="hidden" name="uP_sparam" value="targetRestriction" />
												<input type="hidden" name="targetRestriction" value="no targetRestriction parameter" />
												<input type="hidden" name="uP_sparam" value="targetAction" />
												<input type="hidden" name="targetAction" value="no targetAction parameter" />
												<input type="hidden" name="uP_sparam" value="selectedID" />
												<input type="hidden" name="selectedID" value="" />
												<input type="hidden" name="uP_cancel_targets" value="true" />
												<input type="hidden" name="uP_sparam" value="mode" />
												<input type="hidden" name="mode" value="view" />
												<input type="hidden" name="uP_sparam" value="viewSiteMap" />
												<input type="hidden" name="viewSiteMap" value="" />
			                            		<xsl:call-template name = "TOP_BUTTONS" >
			                                		<xsl:with-param name="type">BACK</xsl:with-param>
			                                		<!--<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_root=root&amp;uP_reload_layout=true&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true&amp;uP_sparam=mode&amp;mode=view</xsl:with-param> -->
			                                		<xsl:with-param name="shortLabel" select="$token[@name='BACK_HOME_LABEL']" />
			                                		<xsl:with-param name="longLabel" select="$token[@name='BACK_HOME_LONG_LABEL']" />
			                                	</xsl:call-template>
                                			</form>
                                		</xsl:when>
                                	  
                                		<xsl:otherwise>
                                			<form action="{$baseActionURL}" method="get">
												<input type="hidden" name="uP_root" value="root" />
												<input type="hidden" name="uP_reload_layout" value="true" />
												<input type="hidden" name="uP_sparam" value="targetRestriction" />
												<input type="hidden" name="targetRestriction" value="no targetRestriction parameter" />
												<input type="hidden" name="uP_sparam" value="targetAction" />
												<input type="hidden" name="targetAction" value="no targetAction parameter" />
												<input type="hidden" name="uP_sparam" value="selectedID" />
												<input type="hidden" name="selectedID" value="" />
												<input type="hidden" name="uP_cancel_targets" value="true" />
												<input type="hidden" name="uP_sparam" value="mode" />
												<input type="hidden" name="mode" value="view" />
			                            		<xsl:call-template name = "TOP_BUTTONS" >
			                                		<xsl:with-param name="type">HOME</xsl:with-param>
			                                		<!--<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_root=root&amp;uP_reload_layout=true&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true&amp;uP_sparam=mode&amp;mode=view</xsl:with-param> -->
			                                		<xsl:with-param name="shortLabel" select="$token[@name='HOME_LABEL']" />
			                                		<xsl:with-param name="longLabel" select="$token[@name='HOME_LONG_LABEL']" />
			                                	</xsl:call-template>
                                			</form>
                                		</xsl:otherwise>
                                	</xsl:choose>
                                </li>
                                <xsl:if test = "not($isFocused)">
	                                <li>
                            			<form action="{$baseActionURL}" method="get">
											<!--<input type="hidden" name="uP_fname" value="layout-sitemap" />
											<input type="hidden" name="uP_sparam" value="targetRestriction" />
											<input type="hidden" name="targetRestriction" value="no targetRestriction parameter" />
											<input type="hidden" name="uP_sparam" value="targetAction" />
											<input type="hidden" name="targetAction" value="no targetAction parameter" />
											<input type="hidden" name="uP_sparam" value="selectedID" />
											<input type="hidden" name="selectedID" value="" />
											<input type="hidden" name="uP_cancel_targets" value="true" /> -->
											<!-- viewSiteMap -->
											<input type="hidden" name="uP_sparam" value="viewSiteMap" />
											<input type="hidden" name="viewSiteMap" value="true" />
		                                	<xsl:call-template name = "TOP_BUTTONS" >
		                                		<xsl:with-param name="type">SITEMAP</xsl:with-param>
		                                		<!--<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_fname=layout-sitemap&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true</xsl:with-param> -->
		                                		<xsl:with-param name="shortLabel" select="$token[@name='SITEMAP_LABEL']" />
		                                		<xsl:with-param name="longLabel" select="$token[@name='SITEMAP_LONG_LABEL']" />
		                                	</xsl:call-template>
                            			</form>
	                                </li>
                                </xsl:if>
                                <xsl:if test="$SHOW_PORTLET_MANAGER='true' and not($isFocused)">
                                    <li>
                            			<form action="{$baseActionURL}" method="get">
											<input type="hidden" name="uP_fname" value="portal/channelmanager/general" />                            	
		                                	<xsl:call-template name = "TOP_BUTTONS" >
		                                		<xsl:with-param name="type">PORTLET_MANAGER</xsl:with-param>
		                                		<!--<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_fname=portal/channelmanager/general</xsl:with-param> -->
		                                		<xsl:with-param name="shortLabel" select="$token[@name='CHANNEL_MANAGER_LABEL']" />
		                                		<xsl:with-param name="longLabel" select="$token[@name='CHANNEL_MANAGER_LONG_LABEL']" />
		                                	</xsl:call-template>
                            			</form>
                                    </li>
                                </xsl:if>
                                <xsl:if test="$userLayoutRoot='root' and not($isSiteMap)">
                                    <xsl:choose>
                                        <xsl:when test="$mode='view' and $SHOW_PREFERENCES='true'">
                                            <li>
	                                			<form action="{$baseActionURL}" method="get">
													<input type="hidden" name="uP_sparam" value="mode" />
													<input type="hidden" name="mode" value="preferences" />
													<input type="hidden" name="uP_sparam" value="focusedTabID" />
													<input type="hidden" name="focusedTabID" value="{$focusedTabID}" />
				                                	<xsl:call-template name = "TOP_BUTTONS" >
				                                		<xsl:with-param name="type">PREFERENCES_ON</xsl:with-param>
				                                		<!--<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_sparam=mode&amp;mode=preferences&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" /></xsl:with-param> -->
				                                		<xsl:with-param name="shortLabel" select="$token[@name='TURN_ON_PREFERENCES_LABEL']" />
				                                		<xsl:with-param name="longLabel" select="$token[@name='TURN_ON_PREFERENCES_LONG_LABEL']" />
				                                	</xsl:call-template>
		                            			</form>
                                            </li>
                                        </xsl:when>
                                        <xsl:when test="$mode='preferences'">
                                            <li>
		                            			<form action="{$baseActionURL}" method="get">
													<input type="hidden" name="uP_sparam" value="mode" />
													<input type="hidden" name="mode" value="view" />
													<input type="hidden" name="uP_sparam" value="focusedTabID" />
													<input type="hidden" name="focusedTabID" value="{$focusedTabID}" />
													<input type="hidden" name="uP_sparam" value="targetRestriction" />
													<input type="hidden" name="targetRestriction" value="no targetRestriction parameter" />
													<input type="hidden" name="uP_sparam" value="targetAction" />
													<input type="hidden" name="targetAction" value="no targetAction parameter" />
													<input type="hidden" name="uP_sparam" value="selectedID" />
													<input type="hidden" name="selectedID" value="" />
													<input type="hidden" name="uP_cancel_targets" value="true" />		                            	
				                                	<xsl:call-template name = "TOP_BUTTONS" >
				                                		<xsl:with-param name="type">PREFERENCES_OFF</xsl:with-param>
				                                		<!--<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_sparam=mode&amp;mode=view&amp;uP_sparam=focusedTabID&amp;focusedTabID=<xsl:value-of select="$focusedTabID" />&amp;uP_sparam=targetRestriction&amp;targetRestriction=no targetRestriction parameter&amp;uP_sparam=targetAction&amp;targetAction=no targetAction parameter&amp;uP_sparam=selectedID&amp;selectedID=&amp;uP_cancel_targets=true</xsl:with-param> -->
				                                		<xsl:with-param name="shortLabel" select="$token[@name='TURN_OFF_PREFERENCES_LABEL']" />
				                                		<xsl:with-param name="longLabel" select="$token[@name='TURN_OFF_PREFERENCES_LONG_LABEL']" />
				                                	</xsl:call-template>
	                                			</form>
                                            </li>
                                            <li>
	                                			<form action="{$baseActionURL}" method="post">
													<input type="hidden" name="uP_sparam" value="uP_save" />
													<input type="hidden" name="uP_save" value="all" />
				                                	<xsl:call-template name = "TOP_BUTTONS" >
				                                		<xsl:with-param name="type">SAVE</xsl:with-param>
				                                		<!--<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_sparam=uP_save&amp;uP_save=all</xsl:with-param> -->
				                                		<xsl:with-param name="shortLabel" select="$token[@name='SAVE_PREFERENCES_LABEL']" />
				                                		<xsl:with-param name="longLabel" select="$token[@name='SAVE_PREFERENCES_LONG_LABEL']" />
				                                	</xsl:call-template>
	                                			</form>
                                            </li>
                                        </xsl:when>
                                    </xsl:choose>
                                </xsl:if>
                                <xsl:if test = "not($isFocused) and $SHOW_LOG_OFF_IN_PERSISTENT_NAV = 'true'">
	                                <li class="last">
                            			<form action="/uP3/logout.jsp" method="post">
	                                	<xsl:call-template name = "TOP_BUTTONS" >
	                                		<xsl:with-param name="type">LOGOFF</xsl:with-param>
	                                		<!--<xsl:with-param name="url">/uP3/logout.jsp</xsl:with-param> -->
	                                		<xsl:with-param name="shortLabel" select="$token[@name='LOGOFF_LABEL']" />
	                                		<xsl:with-param name="longLabel" select="$token[@name='LOGOFF_LONG_LABEL']" />
	                                	</xsl:call-template>
                            			</form>
	                                </li>
                                </xsl:if>
                                <xsl:if test = "$isFocused and /layout/focusedContent/channel[not(@hasHelp='false')]">
	                                <li class="last">
                            			<form action="{$baseActionURL}" method="get">
											<input type="hidden" name="uP_help_target" value="{/layout/focusedContent/channel/@ID}" />
									     	<xsl:call-template name = "TOP_BUTTONS" >
									    		<xsl:with-param name="type">HELP</xsl:with-param>
									    		<!--<xsl:with-param name="url"><xsl:value-of select="$baseActionURL" />?uP_help_target=<xsl:value-of select="/layout/focusedContent/channel/@ID" /></xsl:with-param> -->
									    		<xsl:with-param name="shortLabel" select="$token[@name='FOCUSED_PORTLET_HELP_LABEL']" />
									    		<xsl:with-param name="longLabel" select="$token[@name='FOCUSED_PORTLET_HELP_LONG_LABEL']" />
									    	</xsl:call-template>
                            			</form>
	                                </li>
                                </xsl:if>
                            </ul>
                        </div>
                    </div>
                    <xsl:call-template name = "WELCOME" />
                </xsl:if>
                <!--END: Temporary Header Channel: Home,Prefs,Logout -->
            </div>
        </div>
        <!-- END: Masthead and Header Channel -->
    </xsl:template>


	<!-- ################################################################################# -->
    <!--                                  NAVIGATION                                       -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!--
	<navigation>
		<focusedTab unremovable="false" immutable="false" ID="a23" name="uPortal" />
		<inactiveTab unremovable="true" immutable="false" ID="a31" name="Channels" />
		<inactiveTab unremovable="true" immutable="true" ID="a36" name="Subscription" />
		<inactiveTab unremovable="false" immutable="false" ID="a40" name="Unnamed 2" />
	</navigation> 
	-->
    <xsl:template match="navigation">
        <!-- Begin Tab Block -->
        <div id="portal-tabs">
            <div id="portal-tabs-inner">
                <xsl:call-template name = "TAB_WRAPPER" />
            </div>
        </div>
        <!-- End Tab Block -->
    </xsl:template>



	<!-- ################################################################################# -->
    <!--                                    LOGIN                                          -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!--
	<login>
      <channel ... />
   </login>
	-->
    <xsl:template match="login">
        <xsl:call-template name = "LOGIN" />
    </xsl:template>


	<!-- ################################################################################# -->
    <!--                                    FOOTER                                         -->
	<!-- ################################################################################# -->
	<!-- SAMPLE XML -->
	<!--
	<footer />
	-->
    <xsl:template match="footer">    
    	<xsl:call-template name = "FOOTER" />
    </xsl:template>


</xsl:stylesheet>