<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
        xmlns:xalan="http://xml.apache.org/xalan"
        xmlns:portal="http://uportal.org/portalUrl"
        xmlns:rendering="http://uportal.org/renderingUrl"
        xmlns:layout="http://uportal.org/layoutUrl"
        extension-element-prefixes="portal rendering layout">
    <xsl:output method="xml" indent="no" omit-xml-declaration="yes" encoding="iso-8859-1"
        doctype-system="http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-strict.dtd"
        doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"/>
    
    <!-- Xalan extension element component declaration -->
    <!-- general portal URL construction elements -->
    <xalan:component prefix="portal" elements="url">
        <xalan:script lang="javaclass" src="org.jasig.portal.url.PortalUrlXalanElements"/>
    </xalan:component>
    <!-- rendering attribute URL construction elements -->
    <xalan:component prefix="rendering" elements="attribute parameter">
        <xalan:script lang="javaclass" src="org.jasig.portal.rendering.attributes.url.RenderingAttributeProviderXalanElements"/>
    </xalan:component>
    <!-- layout management extension elements -->
    <xalan:component prefix="layout" elements="addFolder clearMarkings reloadLayout addNode addMarkings moveMarkings removeNode renameNode moveNode">
        <xalan:script lang="javaclass" src="org.jasig.portal.layout.uportal2.LegacyLayoutSourceXalanElements"/>
    </xalan:component>
    
    
    <!-- Param: backID
         The ID of the element that any 'Back to' link should point to. -->
    <xsl:param name="backID"/>

    <!-- Key: layoutNodes
        A key of all folders and portlets so we don't have to do // searches -->
    <xsl:key name="layoutNodes" match="menu|tab|page|column|portlet|inactivePortlet" use="@ID"/>
    
    <!-- Variable: defaultPageName
         The folder name for the default page of a tab/section -->
    <xsl:variable name="defaultPageName">default</xsl:variable>
    
    <xsl:variable name="mode" select="/portalContent/@mode"/>
    <xsl:variable name="activeNodeID" select="/portalContent/@activeNodeID"/>
    
    <!-- Variable: mediaPath
         The URL path to the media files used by this theme -->
    <xsl:variable name="mediaPath">media</xsl:variable>
    
    <!-- Pointer Variables
         Use these variables for shortcuts directly to active content. -->
    <xsl:variable name="activePortletID" select="key('layoutNodes', $activeNodeID)[name() = 'portlet']/@ID"/>
    <xsl:variable name="activePortlet" select="key('layoutNodes', $activePortletID)"/>
    
    <xsl:variable name="activePageID">
        <xsl:choose>
            <!-- When: The active node is a page
                 Then: Use the active node -->
            <xsl:when test="(name(key('layoutNodes', $activeNodeID)) = 'page')">
                <xsl:value-of select="$activeNodeID"/>
            </xsl:when>
            <!-- Otherwise: Use the page the node exists on -->
            <xsl:otherwise>
                <xsl:value-of select="key('layoutNodes', $activeNodeID)/ancestor::page[1]/@ID"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="activePage" select="key('layoutNodes', $activePageID)"/>
    
    <xsl:variable name="activeSectionID" select="$activePage/ancestor::tab[1]/@ID"/>
    <xsl:variable name="activeSection" select="key('layoutNodes', $activeSectionID)"/>
    
    <xsl:variable name="activeTabID" select="$activePage/ancestor::tab[last()]/@ID"/>
    <xsl:variable name="activeTab" select="key('layoutNodes', $activeTabID)"/>
    
    <xsl:variable name="activeMenuID" select="key('layoutNodes', $activeNodeID)/ancestor-or-self::menu[last()]/@ID"/>
    <xsl:variable name="activeMenu" select="key('layoutNodes', $activeMenuID)"/>
    
    <!-- Content Pointers -->
    <xsl:variable name="pageHeader" select="/portalContent/layout/header"/>
    <xsl:variable name="pageFooter" select="/portalContent/layout/footer"/>
    
    <xsl:variable name="userGreeting">Greeting</xsl:variable>
    <!--<xsl:variable name="userGreeting" select="/portalContent/layout/column[@name = 'pageContent']/portlet[@fname = 'userGreeting']"/>-->
    <xsl:variable name="searchForm">Form</xsl:variable>
    <!--<xsl:variable name="searchForm" select="/portalContent/layout/column[@name = 'pageContent']/portlet[@fname = 'searchForm']"/>-->
    
    <xsl:variable name="activeTabDisplayName" select="$activeTab/attribute[@name = 'displayName']/@value"/>
    
    <xsl:variable name="activePageDisplayName">
        <xsl:choose>
            <!-- When: There is a displayName attribute
                Then: Use the displayName -->
            <xsl:when test="($activePage/attribute[@name = 'displayName']/@value)">
                <xsl:value-of select="$activePage/attribute[@name = 'displayName']/@value"/>
            </xsl:when>
            <!-- Otherwise: Use the sections's name -->
            <xsl:otherwise>
                <xsl:value-of select="$activeSection/attribute[@name = 'displayName']/@value"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    
    <xsl:variable name="helpUrl">http://help.com</xsl:variable>
    
    <xsl:variable name="logoutUrl">http://logout.com</xsl:variable>
    
    <xsl:variable name="tabs" select="/portalContent/layout/tab"/>
    <xsl:variable name="sections" select="$activeTab/tab"/>

    
    <!-- Template: portalContent -->
    <xsl:template match="portalContent">
        <!-- This allows for differnet page layouts based on mode -->
        <!-- Note to self: Could AJAX-compatible rendering of channel content be done here ;) -->
        <xsl:choose>
            <xsl:when test="($mode = 'detached')">
                <xsl:apply-templates select="portlet" mode="detached"/>
            </xsl:when>
            <xsl:when test="($mode = 'menu')">
                <xsl:apply-templates select="layout" mode="menu"/>
            </xsl:when>
            <xsl:when test="($mode = 'focused')">
                <xsl:apply-templates select="layout" mode="focused"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates select="layout"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    
    <xsl:template name="getDisplayName">
        <xsl:param name="nodeID"/>
        <xsl:variable name="thisNode" select="key('layoutNodes', $nodeID)"/>
        
        <xsl:choose>
            <xsl:when test="$thisNode/attribute[@name = 'displayName']/@value">
                <xsl:value-of select="$thisNode/attribute[@name = 'displayName']/@value"/>
            </xsl:when>
            <xsl:when test="name($thisNode) = 'portlet'">
                <xsl:value-of select="$thisNode/displayName"/>
            </xsl:when>
            <xsl:when test="name($thisNode) = 'inactivePortlet'">
                <xsl:value-of select="$thisNode/displayName"/>
            </xsl:when>
            <xsl:when test="name($thisNode) = 'page'">
                <xsl:value-of select="$activeSection/attribute[@name = 'displayName']/@value"/>
            </xsl:when>
            <xsl:when test="name($thisNode) = 'tab'">
                <xsl:value-of select="$thisNode/@name"/>
            </xsl:when>
            <xsl:otherwise>Unknown (<xsl:value-of select="$nodeID"/>)</xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    

    <!-- ======================================================================
        Detached Mode Page Layout
        ======================================================================= -->
    <xsl:template match="portlet" mode="detached">
        <html>
            <head>
                <title><xsl:value-of select="portlet/displayName"/> - uPortal</title>
                <link rel="stylesheet" type="text/css" href="{$mediaPath}/styles/common.css"/>
            </head>
            <body>
                <xsl:copy-of select="."/>
            </body>
        </html>
    </xsl:template>


    <!-- ======================================================================
        Focused Mode Page Layout
    ======================================================================= -->
    <xsl:template match="layout" mode="focused">
        <html>
            <head>
                <title>
                    <xsl:call-template name="getDisplayName">
                        <xsl:with-param name="nodeID" select="$activePortletID"/>
                    </xsl:call-template>
                    <xsl:text> - uPortal</xsl:text>
                </title>
                <link rel="stylesheet" type="text/css" href="{$mediaPath}/styles/common.css"/>
                <xsl:comment>[if gte IE 5.5000]&gt; &lt;script src="<xsl:value-of select="$mediaPath"/>/scripts/png-hack.js" type="text/javascript"&gt; &lt;/script&gt; &lt;![endif]</xsl:comment>
            </head>
            <body>
                <!-- Renders a portlet in a transient folder passing the structure transform the nodeID of the
                     portlet rendered 
                <portal:url>
                    <tlayout:portlet fname="ContentSubscriber"/>
                </portal:url>
                -->
                
                <!-- Begin: Portal Header -->
                <div id="portalHeader">
                    <!-- Begin: System Menu -->
                    <div id="portalSystemMenu">
                        <ul class="up-toolbar">
                            <li class="up-toolbar-button">
                                <a href="{$logoutUrl}"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Logout</a>
                            </li>
                        </ul>
                        <div class="up-border-bl">
                            <xsl:text> </xsl:text>
                        </div>
                    </div>
                    <!-- End: System Menu -->
                    <div id="portalFocusedTitle" style="position: relative;">
                        <xsl:if test="$activePortlet/attribute[@name = 'iconUrl']/@value">
                            <xsl:attribute name="class">up-show-portlet-icon</xsl:attribute>
                            <div class="up-portlet-icon"><img src="{$activePortlet/attribute[@name = 'iconUrl']/@value}" alt="" width="16" height="16"/></div>
                        </xsl:if>
                        <div class="up-portlet-title">
                            <xsl:call-template name="getDisplayName">
                                <xsl:with-param name="nodeID" select="$activePortletID"/>
                            </xsl:call-template>
                        </div>
                    </div>
                    <!-- Begin: Tab Base -->
                    <div id="portalTabBase">
                        <xsl:if test="$activePortlet/attribute[@name = 'iconUrl']/@value">
                            <xsl:attribute name="class">up-show-portlet-icon</xsl:attribute>
                        </xsl:if>
                        <table class="up-layout">
                            <tr class="valign-middle">
                                <td class="up-layout align-left width-100">
                                    <div id="portalFocusedPortletToolbar">
                                        <xsl:variable name="validBackID">
                                            <xsl:choose>
                                                <!-- When: The backID is a valid layout node
                                                     Then: Use the node -->
                                                <xsl:when test="(key('layoutNodes', $backID))">
                                                    <xsl:value-of select="$backID"/>
                                                </xsl:when>
                                                <!-- When: The portlet is in a column on a page
                                                     Then: Use the page -->
                                                <xsl:when test="(name($activePortlet/../..) = 'page')">
                                                    <xsl:value-of select="$activePortlet/../../@ID"/>
                                                </xsl:when>
                                                <!-- Otherwise: Use the first tab -->
                                                <xsl:otherwise>
                                                    <xsl:value-of select="/portalContent/layout/tab[1]/@ID"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:variable>
                                        <xsl:variable name="backUrl">
                                            <!-- PETER URL: session scoped, set structure param 'nodeID' to {$validBackID} -->
                                            <portal:url>
                                                <rendering:parameter provider="structure" name="nodeID" value="{$validBackID}"/>
                                            </portal:url>
                                        </xsl:variable>
                                        <xsl:variable name="backName">
                                            <xsl:call-template name="getDisplayName">
                                                <xsl:with-param name="nodeID" select="$validBackID"/>
                                            </xsl:call-template>
                                        </xsl:variable>
                                        <ul class="up-toolbar">
                                            <li class="up-toolbar-button">
                                                <a href="{$backUrl}"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Back to <xsl:value-of select="$backName"/></a>
                                            </li>
                                            <!--
                                            <li class="up-toolbar-button">
                                                <a href="#TODO"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Settings</a>
                                            </li>
                                            <li class="up-toolbar-button">
                                                <a href="#TODO"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Help</a>
                                            </li>
                                            -->
                                        </ul>
                                    </div>
                                </td>
                            </tr>
                        </table>
                    </div>
                    <!-- End: Tab Base -->
                </div>
                <!-- End: Portal Header -->
                <div id="portalFocusedPortletContent">
                    <xsl:copy-of select="$activePortlet"/>
                </div>
            </body>
        </html>
    </xsl:template>

    
    <!-- ======================================================================
      Menu Mode Page Layout
    ======================================================================= -->
    <xsl:template match="layout" mode="menu">
        <html>
            <head>
                <title>
                    <xsl:call-template name="getDisplayName">
                        <xsl:with-param name="nodeID" select="$activeMenuID"/>
                    </xsl:call-template>
                    <xsl:text> - uPortal</xsl:text>
                </title>
                <link rel="stylesheet" type="text/css" href="{$mediaPath}/styles/common.css"/>
                <xsl:comment>[if gte IE 5.5000]&gt; &lt;script src="<xsl:value-of select="$mediaPath"/>/scripts/png-hack.js" type="text/javascript"&gt; &lt;/script&gt; &lt;![endif]</xsl:comment>
            </head>
            <body>
                <!-- Begin: Portal Header -->
                <div id="portalHeader">
                    <!-- Begin: System Menu -->
                    <div id="portalSystemMenu">
                        <ul class="up-toolbar">
                            <li class="up-toolbar-button">
                                <a href="{$logoutUrl}"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Logout</a>
                            </li>
                        </ul>
                        <div class="up-border-bl">
                            <xsl:text> </xsl:text>
                        </div>
                    </div>
                    <!-- End: System Menu -->
                    <div id="portalMenuTitle">
                        <xsl:call-template name="getDisplayName">
                            <xsl:with-param name="nodeID" select="$activeMenuID"/>
                        </xsl:call-template>
                    </div>
                    <!-- Begin: Tab Base -->
                    <div id="portalTabBase">
                        <xsl:if test="$activeMenu/attribute[@name = 'iconUrl']/@value">
                            <xsl:attribute name="class">up-show-portlet-icon</xsl:attribute>
                        </xsl:if>
                        <table class="up-layout">
                            <tr class="valign-middle">
                                <td class="up-layout align-left width-100">
                                    <div id="portalFocusedPortletToolbar">
                                        <xsl:variable name="validBackID">
                                            <xsl:choose>
                                                <!-- When: The backID is a valid layout node
                                                    Then: Use the node -->
                                                <xsl:when test="(key('layoutNodes', $backID))">
                                                    <xsl:value-of select="$backID"/>
                                                </xsl:when>
                                                <!-- Otherwise: Use the first tab -->
                                                <xsl:otherwise>
                                                    <xsl:value-of select="/portalContent/layout/tab[1]/@ID"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:variable>
                                        <xsl:variable name="backUrl">
                                            <!-- PETER URL: session scoped, set structure param 'nodeID' to {$validBackID} -->
                                            <portal:url>
                                                <rendering:parameter provider="structure" name="nodeID" value="{$validBackID}"/>
                                            </portal:url>
                                        </xsl:variable>
                                        <xsl:variable name="backName">
                                            <xsl:call-template name="getDisplayName">
                                                <xsl:with-param name="nodeID" select="$validBackID"/>
                                            </xsl:call-template>
                                        </xsl:variable>
                                        <ul class="up-toolbar">
                                            <li class="up-toolbar-button">
                                                <a href="{$backUrl}"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Back to <xsl:value-of select="$backName"/></a>
                                            </li>
                                        </ul>
                                    </div>
                                </td>
                            </tr>
                        </table>
                    </div>
                    <!-- End: Tab Base -->
                </div>
                <!-- End: Portal Header -->
                <table class="up-layout">
                    <tr class="valign-top">
                        <td class="up-layout" id="portalMenuNavContainer">
                            <div id="portalMenuNav" class="up-portlet up-show-portlet-border">
                                <div class="up-border-tl">
                                    <div class="up-border-tr">
                                        <xsl:text> </xsl:text>
                                    </div>
                                </div>
                                <div class="up-portlet-content">
                                    <div id="portalMenuNavHeader">
                                        Choose an item below:
                                        <!--<xsl:call-template name="getDisplayName">
                                            <xsl:with-param name="nodeID" select="$activeMenuID"/>
                                        </xsl:call-template>-->
                                    </div>
                                    <ul>
                                        <xsl:for-each select="$activeMenu/descendant-or-self::menu | $activeMenu/descendant-or-self::portlet | $activeMenu/descendant-or-self::inactivePortlet">
                                            <xsl:choose>
                                                <xsl:when test="(name(.) = 'menu')">
                                                    <li class="up-menu-item up-menu-header">
                                                        <xsl:call-template name="getDisplayName">
                                                            <xsl:with-param name="nodeID" select="@ID"/>
                                                        </xsl:call-template>
                                                    </li>
                                                </xsl:when>
                                                <xsl:when test="(@ID = $activePortletID)">
                                                    <li class="up-menu-item up-menu-item-active">
                                                        <xsl:call-template name="getDisplayName">
                                                            <xsl:with-param name="nodeID" select="@ID"/>
                                                        </xsl:call-template>
                                                    </li>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:variable name="menuItemLink">
                                                        <!-- PETER: session scoped, structure transform parameter 'nodeID' set to {@ID} -->
                                                        <portal:url>
                                                            <rendering:parameter provider="structure" name="nodeID" value="{@ID}"/>
                                                        </portal:url>
                                                    </xsl:variable>
                                                    <li class="up-menu-item up-menu-item-inactive">
                                                        <a href="{$menuItemLink}">
                                                            <xsl:call-template name="getDisplayName">
                                                                <xsl:with-param name="nodeID" select="@ID"/>
                                                            </xsl:call-template>
                                                        </a>
                                                    </li>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:for-each>
                                    </ul>
                                </div>
                                <div class="up-border-bl">
                                    <div class="up-border-br">
                                        <xsl:text> </xsl:text>
                                    </div>
                                </div>
                            </div>
                        </td>
                        <td class="up-layout" id="portalMenuContentContainer">
                            <xsl:choose>
                                <xsl:when test="($activePortletID != '')">
                                    <div class="up-portlet-title">
                                        <xsl:call-template name="getDisplayName">
                                            <xsl:with-param name="nodeID" select="$activePortletID"/>
                                        </xsl:call-template>
                                    </div>
                                    <xsl:copy-of select="$activePortlet"/>
                                </xsl:when>
                                <xsl:otherwise>Choose a menu item on the left.</xsl:otherwise>
                            </xsl:choose>
                        </td>
                    </tr>
                </table>
            </body>
        </html>
    </xsl:template>
    
    
    
    <!-- ======================================================================
        Standard Mode Page Layout
    ======================================================================= -->
    <xsl:template match="layout">
        <!-- Collier: I moved this variable declaration here, since for some bizzare reason, XSLT extensions doesnt' allow use of
             extension elements outside of the template context -->
        <xsl:variable name="settingsMenuUrl">
            <!-- PETER URL: session scoped, structure attribute 'nodeID' set to {/portalContent/menu[@name = 'settingsMenu']} -->
            <portal:url>
                <rendering:parameter provider="structure" name="nodeID" value="{//menu[@name = 'settingsMenu']/@ID}"/>
            </portal:url>
        </xsl:variable>
    
        <xsl:variable name="logoutUrl2">
            <!-- this example specifies parentId, so that nodes will be added right away -->
            <portal:url>
                <layout:addFolder name="newTab" parentId="root" nextId="a25">
                    <layout:attribute provider="structure" name="folderType" value="tab"/>
                    <layout:attribute name="displayName" provider="layout" value="Newlyadded Tab"/>
                    <layout:addFolder name="column1">
                        <layout:attribute name="folderType" provider="structure" value="page"/>
                    </layout:addFolder>
                    <layout:addFolder name="column2">
                        <layout:attribute name="folderType" provider="structure" value="page"/>
                    </layout:addFolder>
                </layout:addFolder>
            </portal:url>
        </xsl:variable>
        
        
        <xsl:variable name="helpUrl2">
            <!-- example of adding folder structure -->
            <!-- this example does not specify where the nodes should be placed, so
            this will cause add markings to be turned on (to ask the user for a location)
            -->
            <portal:url>
                <layout:addFolder name="newTab">
                    <layout:attribute provider="structure" name="folderType" value="tab"/>
                    <layout:attribute name="displayName" provider="layout" value="Newlyadded Tab"/>
                    <layout:addFolder name="column1">
                        <layout:attribute name="folderType" provider="structure" value="page"/>
                    </layout:addFolder>
                    <layout:addFolder name="column2">
                        <layout:attribute name="folderType" provider="structure" value="page"/>
                    </layout:addFolder>
                </layout:addFolder>
            </portal:url>
        </xsl:variable>
        
        
        <html xmlns="http://www.w3.org/1999/xhtml">
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"/>
                <title>
                    <xsl:call-template name="getDisplayName">
                        <xsl:with-param name="nodeID" select="$activePageID"/>
                    </xsl:call-template>
                    <xsl:text> - uPortal</xsl:text>
                </title>
                <link rel="stylesheet" type="text/css" href="{$mediaPath}/styles/common.css"/>
                <xsl:comment>[if gte IE 5.5000]&gt; &lt;script src="<xsl:value-of select="$mediaPath"/>/scripts/png-hack.js" type="text/javascript"&gt; &lt;/script&gt; &lt;![endif]</xsl:comment>
            </head>
            <body>
                <!--<xsl:call-template name="debugOutput"/>-->
                <!-- Begin: Portal Header -->
                <div id="portalHeader">
                    <!-- Begin: System Menu -->
                    <div id="portalSystemMenu">
                        <ul class="up-toolbar">
                            <li class="up-toolbar-button">
                                <a href="{$settingsMenuUrl}"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Settings</a>
                            </li>
                            <li class="up-toolbar-button">
                                <a href="{$helpUrl2}"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Help</a>
                            </li>
                            <li class="up-toolbar-button">
                                <a href="{$logoutUrl2}"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Logout</a>
                            </li>
                        </ul>
                        <div class="up-border-bl">
                            <xsl:text> </xsl:text>
                        </div>
                    </div>
                    <!-- End: System Menu -->
                    <!-- Begin: Tab Bar -->
                    <div id="portalTabBar">
                        <table class="up-layout">
                            <tr class="valign-bottom">
                                <td class="up-layout valign-bottom">
                                    <div id="portalLogo">
                                        <img src="{$mediaPath}/images/uportal-logo.png" alt="uPortal" height="65" width="110"/>
                                    </div>
                                </td>
                                <!-- tatst -->
                                <xsl:for-each select="$tabs">
                                    <xsl:apply-templates select="." mode="tab"/>
                                </xsl:for-each>
                                <td class="up-spacer">
                                    <xsl:text> </xsl:text>
                                </td>
                            </tr>
                        </table>
                    </div>
                    <!-- End: Tab Bar -->
                    <!-- Begin: Tab Base -->
                    <div id="portalTabBase">
                        <table class="up-layout">
                            <tr class="valign-middle">
                                <td class="up-layout align-left width-100">
                                    <!-- Begin: Greeting -->
                                    <div id="portalGreeting"><xsl:copy-of select="$userGreeting"/></div>
                                    <!-- End: Greeting -->
                                </td>
                                <td class="up-layout align-right">
                                    <!-- Begin: Search Form -->
                                    <div id="portalGreeting"><xsl:copy-of select="$searchForm"/></div>
                                    <!-- End: Search Form -->
                                </td>
                            </tr>
                        </table>
                    </div>
                    <!-- End: Tab Base -->
                </div>
                <!-- End: Portal Header -->
                <table class="up-layout">
                    <tr>
                        <xsl:if test="(count($sections) &gt; 0)">
                            <td id="portalSidebarContainer" class="up-layout valign-top">
                                <!-- Begin: Sidebar -->
                                <div id="portalSidebar">
                                    <div class="up-border-tr">
                                        <xsl:text> </xsl:text>
                                    </div>
                                    <!-- Begin: Section Nav -->
                                    <div id="portalSectionNav">
                                        <div id="portalSectionNavLabel">Choose a section:</div>
                                        <div id="portalSections">
                                            <div class="up-border-tl">
                                                <div class="up-border-tr">
                                                    <xsl:text> </xsl:text>
                                                </div>
                                            </div>
                                            <ul>
                                                <xsl:variable name="sectionTabs" select="$activeTab | $sections"/>
                                                <xsl:for-each select="$sectionTabs">
                                                    <xsl:apply-templates select="." mode="section">
                                                        <xsl:with-param name="isLast" select="position() = last()"/>
                                                    </xsl:apply-templates>
                                                </xsl:for-each>
                                            </ul>
                                            <!--<xsl:copy-of select="$activeTab | $sections"/>-->
                                            <div class="up-border-bl">
                                                <div class="up-border-br">
                                                    <xsl:text> </xsl:text>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                    <!-- End: Section Nav -->
                                    <div class="up-border-br">
                                        <xsl:text> </xsl:text>
                                    </div>
                                </div>
                                <!-- End: Sidebar -->
                            </td>
                        </xsl:if>
                        <td id="portalPageContainer" class="up-layout valign-top">
                            <div id="portalPage">
                                <div id="portalPageInfo">
                                    <table class="up-layout">
                                        <tr>
                                            <td class="up-layout valign-middle">
                                                <xsl:call-template name="breadcrumbs"/>
                                            </td>
                                            <!-- Currently Disabled
                                            <td class="up-layout valign-middle align-right">
                                                <div id="portalPageCustomizationMenu">
                                                    <ul class="up-toolbar">
                                                        <li class="up-toolbar-button">
                                                            <a href="#"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Add Content</a>
                                                        </li>
                                                        <li class="up-toolbar-button menu">
                                                            <a href="#"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>Change Layout</a>
                                                        </li>
                                                    </ul>
                                                </div>
                                            </td>
                                            -->
                                        </tr>
                                    </table>
                                </div>
                                <div id="portalPageContent">
                                    <table class="up-layout">
                                        <tr>
                                            <xsl:for-each select="$activePage/column">
                                                <td class="up-layout valign-top">
                                                    <xsl:if test="attribute[@name = 'columnWidth']/@value">
                                                        <xsl:attribute name="style">
                                                            <xsl:text>width: </xsl:text>
                                                            <xsl:value-of select="attribute[@name = 'columnWidth']/@value"/>
                                                            <xsl:text>%;</xsl:text>
                                                        </xsl:attribute>
                                                    </xsl:if>
                                                    <div class="up-column">
                                                        <xsl:apply-templates select="portlet"/>
                                                    </div>
                                                </td>
                                            </xsl:for-each>
                                        </tr>
                                    </table>
                                </div>
                            </div>
                        </td>
                    </tr>
                </table>
                <!-- Begin: Portal Footer -->
                <div id="portalFooter">
                    <xsl:apply-templates select="$pageFooter/portlet"/>
                </div>
                <!-- End: Portal Footer -->
                <!--<xsl:call-template name="debugOutput"/>-->
            </body>
        </html>
    </xsl:template>
    
    
    <!-- ======================================================================
      Template: Tabs
    ======================================================================= -->    
    <xsl:template match="tab" mode="tab">
        <td class="up-layout valign-bottom">
            <div>
                <xsl:attribute name="class">
                    <xsl:text>up-tab </xsl:text>
                    <xsl:choose>
                        <xsl:when test="(@ID = $activeTabID)">
                            <xsl:text>up-tab-active</xsl:text>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text>up-tab-inactive</xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:attribute>
                <div class="up-border-tl"><div class="up-border-tr"><xsl:text> </xsl:text></div></div>
                <xsl:variable name="tabUrl">
                    <!-- PETER: Session scoped, set structure attribute 'nodeID' to {@ID} -->
                    <portal:url>
                        <rendering:parameter provider="structure" name="nodeID" value="{@ID}"/>
                    </portal:url>
                </xsl:variable>
                <a href="{$tabUrl}"><span><img src="{$mediaPath}/images/icon-home-xsmall.png" alt="" width="16" height="16"/>
                    <xsl:call-template name="getDisplayName">
                        <xsl:with-param name="nodeID" select="@ID"/>
                    </xsl:call-template>
                </span></a>
            </div>
        </td>
    </xsl:template>

    
    <!-- ======================================================================
      Template: Sections
    ======================================================================= -->
    <xsl:template match="tab" mode="section">
        <xsl:param name="isLast">false</xsl:param>
        <li>
            <xsl:attribute name="class">
                <xsl:text>up-section </xsl:text>
                <!--<xsl:if test="(@ID = $activeTabID)">-->
                    <xsl:text>up-section-root </xsl:text>
                <!--</xsl:if>-->
                <xsl:choose>
                    <xsl:when test="(@ID = $activeSectionID)">
                        <xsl:text>up-section-active </xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>up-section-inactive </xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:if test="($isLast = 'true')">
                    <xsl:text>last </xsl:text>
                </xsl:if>
            </xsl:attribute>
            <xsl:variable name="sectionUrl">
                <!-- PETER: Session scoped, set structure attribute 'nodeID' to {@ID} -->
                <portal:url>
                        <rendering:parameter provider="structure" name="nodeID" value="{@ID}"/>
                </portal:url>
            </xsl:variable>
            <a class="link" href="{$sectionUrl}"><img src="{$mediaPath}/images/icon-sample-xsmall.png" alt="" width="16" height="16"/>
                <xsl:call-template name="getDisplayName">
                    <xsl:with-param name="nodeID" select="@ID"/>
                </xsl:call-template>
            </a>
        </li>
    </xsl:template>
    
    
    <!-- ======================================================================
      Template: Breadcrumbs
    ======================================================================= -->    
    <xsl:template name="breadcrumbs">
        <div id="portalPageBreadcrumbs">
            <xsl:for-each select="$activePage/ancestor-or-self::page">
                <xsl:variable name="pageName">
                    <xsl:call-template name="getDisplayName">
                        <xsl:with-param name="nodeID" select="@ID"/>
                    </xsl:call-template>
                </xsl:variable>
                <xsl:choose>
                    <xsl:when test="(position() != last())">
                        <xsl:variable name="pageUrl">
                            <!-- PETER: Session scoped, set structure attribute 'nodeID' to {@ID} -->
                            <portal:url>
                                <rendering:parameter provider="structure" name="nodeID" value="{@ID}"/>
                            </portal:url>
                        </xsl:variable>
                        <a href="{$pageUrl}">
                            <xsl:value-of select="$pageName"/>
                        </a>
                        <xsl:text> &gt; </xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$pageName"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </div>
    </xsl:template>


    <!-- ======================================================================
      Template: Portlet
    ======================================================================= -->
    <xsl:template match="portlet">
        <xsl:variable name="showBorder" select="not(attribute[@name = 'showBorder']/@value = 'false')"/>
        <xsl:variable name="showTitlebar" select="$showBorder and not(attribute[@name = 'showTitlebar']/@value = 'false')"/>
        <div>
            <xsl:attribute name="class">
                <xsl:text>up-portlet </xsl:text>
                <xsl:if test="($showBorder)">
                    <xsl:text>up-show-portlet-border </xsl:text>
                    <xsl:if test="($showTitlebar)">
                        <xsl:text>up-show-portlet-titlebar </xsl:text>
                    </xsl:if>
                </xsl:if>
            </xsl:attribute>
            <xsl:if test="($showBorder)">
                <div class="up-border-tl">
                    <div class="up-border-tr">
                        <xsl:text> </xsl:text>
                    </div>
                </div>
            </xsl:if>
            <!-- Begin: Portlet Titlebar -->
            <xsl:if test="($showTitlebar)">
                <xsl:variable name="portletID" select="@ID"/>
                <!-- Begin: Portlet Actions -->
                <!-- Collapse -->
                <xsl:variable name="portletCollapseUrl">
                    <portal:url>
                        <rendering:attribute provider="theme" name="collapsed" value="true"/>
                    </portal:url>
                </xsl:variable>
                <!-- Expand -->
                <xsl:variable name="portletExpandUrl">
                    <portal:url>
                        <rendering:attribute provider="theme" name="collapsed" value="false"/>
                    </portal:url>
                </xsl:variable>
                <!-- Focus -->
                <xsl:variable name="portletFocusUrl">
                    <portal:url>
                        <rendering:parameter provider="structure" name="nodeID" value="{@ID}"/>
                        <rendering:parameter provider="structure" name="backID" value="{$activePageID}"/>
                    </portal:url>
                </xsl:variable>
                <!-- Settings -->
                <xsl:variable name="portletSettingsUrl">
                    <!--
                    <portal:url>
                        <portlet:windowState state="edit"/>
                    </portal:url>
                    -->
                </xsl:variable>
                <!-- Help -->
                <xsl:variable name="portletHelpUrl">
                    <!--
                    <portal:url>
                    <portlet:windowState state="edit"/>
                    </portal:url>
                    -->
                </xsl:variable>
                <!-- Detach -->
                <xsl:variable name="portletDetachUrl">
                    <!--
                    <portal:url>
                        
                    </portal:url>
                    -->
                </xsl:variable>
                <!-- Remove -->
                <xsl:variable name="portletRemoveUrl">
                    <!--
                    <portal:url>
                        <layout:removePortlet/>
                        <layout:save/>
                    </portal:url>
                    -->
                </xsl:variable>
                <!-- Move  -->
                <xsl:variable name="portletMoveUrl">
                    <!--
                    <portal:url>
                        <layout:showMoveTargets/>
                    </portal:url>
                    -->
                </xsl:variable>
                <!-- Begin: Portlet Actions -->
                <div class="up-portlet-titlebar up-show-portlet-icon">
                    <div class="up-portlet-title"><img src="{$mediaPath}/images/icon-home-small.png" alt="" width="24" height="24"/>
                        <xsl:call-template name="getDisplayName">
                            <xsl:with-param name="nodeID" select="@ID"/>
                        </xsl:call-template>
                    </div>
                    
                    <ul class="up-portlet-actions">
                        <li><a href="{$portletSettingsUrl}" title="Settings">[S]</a></li>
                        <li><a href="{$portletHelpUrl}" title="Help">[?]</a></li>
                        <li><a href="{$portletFocusUrl}" title="Focus">[^]</a></li>
                        <li><a href="{$portletDetachUrl}" title="Detach">[#]</a></li>
                        <li><a href="{$portletCollapseUrl}" title="Collapse">[-]</a></li>
                        <li><a href="{$portletRemoveUrl}" title="Remove">[X]</a></li>
                    </ul>
                    <div class="up-clear">
                        <xsl:text> </xsl:text>
                    </div>
                </div>
            </xsl:if>
            <!-- End: Portlet Titlebar -->
            <div style="border: 1px solid #C00;">collapsed: <xsl:value-of select="attribute[@name = 'collapsed']/@value"/></div>
            <div class="up-portlet-content">
               <xsl:copy-of select="."/>
            </div>
            <xsl:if test="($showBorder)">
                <div class="up-border-bl">
                    <div class="up-border-br">
                        <xsl:text> </xsl:text>
                    </div>
                </div>
            </xsl:if>
        </div>
    </xsl:template>

    
    <!-- ======================================================================
      Template: Inactive Portlet
    ======================================================================= -->    
    <xsl:template match="inactivePortlet"/>
    
    
    <!-- ======================================================================
      Template: Debug Output
    ======================================================================= --> 
    <xsl:template name="debugOutput">
        <div style="border: 1px solid #000099; background-color: #CC9999; padding: 5px;">
            <strong>Mode:</strong> <xsl:value-of select="$mode"/><br/>
            <strong>Active Node ID:</strong> <xsl:value-of select="$activeNodeID"/><br/>
            <strong>Active Tab ID:</strong> <xsl:value-of select="$activeTabID"/><br/>
            <strong>Active Section ID:</strong> <xsl:value-of select="$activeSectionID"/><br/>
            <strong>Active Page ID:</strong> <xsl:value-of select="$activePageID"/><br/>
            <strong>Active Portlet ID:</strong> <xsl:value-of select="$activePortletID"/><br/>
            <strong>Active Menu ID:</strong> <xsl:value-of select="$activeMenuID"/><br/>
            <strong>Tree</strong><br/>
            <pre>
                <xsl:copy-of select="/"/>
            </pre>
        </div>
    </xsl:template>
    
</xsl:stylesheet>